MSG_HASH(
      MSG_COMPILER,
      "編譯器"
      )
MSG_HASH(
      MSG_UNKNOWN_COMPILER,
      "未知的編譯器"
      )
MSG_HASH(
      MSG_DEVICE_DISCONNECTED_FROM_PORT,
      "設備已從連接口上移開"
      )
MSG_HASH(
      MSG_UNKNOWN_NETPLAY_COMMAND_RECEIVED,
      "接收到未知的連線遊戲指令"
      )
MSG_HASH(
      MSG_FILE_ALREADY_EXISTS_SAVING_TO_BACKUP_BUFFER,
      "文件已存在。儲存到備份至緩衝區"
      )
MSG_HASH(
      MSG_GOT_CONNECTION_FROM,
      "連接來自： \"%s\""
      )
MSG_HASH(
      MSG_GOT_CONNECTION_FROM_NAME,
      "連接來自： \"%s (%s)\""
      )
MSG_HASH(
      MSG_PUBLIC_ADDRESS,
      "公開地址"
      )
MSG_HASH(
      MSG_NO_ARGUMENTS_SUPPLIED_AND_NO_MENU_BUILTIN,
      "未提供參數也沒有內建選單，顯示幫助..."
      )
MSG_HASH(
      MSG_SETTING_DISK_IN_TRAY,
      "設定光碟機裡光碟"
      )
MSG_HASH(
      MSG_WAITING_FOR_CLIENT,
      "等待客戶端 ..."
      )
MSG_HASH(
      MSG_NETPLAY_YOU_HAVE_LEFT_THE_GAME,
      "你已離開遊戲"
      )
MSG_HASH(
      MSG_NETPLAY_YOU_HAVE_JOINED_AS_PLAYER_N,
      "你已作為玩家 %d 加入"
      )
MSG_HASH(
      MSG_NETPLAY_ENDIAN_DEPENDENT,
      "This core does not support inter-architecture netplay between these systems"
      )
MSG_HASH(
      MSG_NETPLAY_PLATFORM_DEPENDENT,
      "此模擬器且不支援此兩種架構下的連線遊戲模式"
      )
MSG_HASH(
      MSG_NETPLAY_ENTER_PASSWORD,
      "輸入連線遊戲服務器的密碼："
      )
MSG_HASH(
      MSG_NETPLAY_INCORRECT_PASSWORD,
      "密碼錯誤"
      )
MSG_HASH(
      MSG_NETPLAY_SERVER_NAMED_HANGUP,
      "\"%s\" 已斷開連線"
      )
MSG_HASH(
      MSG_NETPLAY_SERVER_HANGUP,
      "連線遊戲客戶端已離開"
      )
MSG_HASH(
      MSG_NETPLAY_CLIENT_HANGUP,
      "已離開連線遊戲模式"
      )
MSG_HASH(
      MSG_NETPLAY_CANNOT_PLAY_UNPRIVILEGED,
      "你沒有遊戲權限"
      )
MSG_HASH(
      MSG_NETPLAY_CANNOT_PLAY_NO_SLOTS,
      "連線遊戲人數已滿" /*FIXME:"There are no free player slots"*/
      )
MSG_HASH(
      MSG_NETPLAY_CANNOT_PLAY,
      "無法切換到遊戲模式"
      )
MSG_HASH(
      MSG_NETPLAY_PEER_PAUSED,
      "連線遊戲對方 \"%s\" 已暫停"
      )
MSG_HASH(
      MSG_NETPLAY_CHANGED_NICK,
      "你的暱稱已修改為 \"%s\""
      )
MSG_HASH(
      MENU_ENUM_SUBLABEL_VIDEO_SHARED_CONTEXT,
      "使用模擬器硬體渲染私人內容時可避免硬體在各frames時的狀態改變."
      )
MSG_HASH(
      MENU_ENUM_SUBLABEL_MENU_SETTINGS,
      "調整選單顯示的相關設定。"
      )
MSG_HASH(
      MENU_ENUM_SUBLABEL_VIDEO_HARD_SYNC,
      "強制同步CPU和GPU，以性能為代價換取低延遲。"
      )
MSG_HASH(
      MENU_ENUM_SUBLABEL_VIDEO_THREADED,
      "以延遲和視訊撕裂為代價換取高性能，當且僅當能\n"
      "達到全速模擬時使用。"
      )
MSG_HASH(
      MSG_AUDIO_VOLUME,
      "聲音音量"
      )
MSG_HASH(
      MSG_AUTODETECT,
      "自動偵測"
      )
MSG_HASH(
      MSG_AUTOLOADING_SAVESTATE_FROM,
      "自動載入存檔從"
      )
MSG_HASH(
      MSG_CAPABILITIES,
      "容量"
      )
MSG_HASH(
      MSG_CONNECTING_TO_NETPLAY_HOST,
      "連線到連線遊戲主機"
      )
MSG_HASH(
      MSG_CONNECTING_TO_PORT,
      "連接到連接口"
      )
MSG_HASH(
      MSG_CONNECTION_SLOT,
      "連接到插槽"
      )
MSG_HASH(
      MSG_SORRY_UNIMPLEMENTED_CORES_DONT_DEMAND_CONTENT_NETPLAY,
      "對不起，錯誤發生：模擬器核心未請求內容，無法加入連線遊戲。"
      )
MSG_HASH(
MSG_FAILED_TO_SET_DISK,
      "設定磁盤失敗")
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_ACCOUNTS_CHEEVOS_PASSWORD,
     "密碼"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_ACCOUNTS_CHEEVOS_SETTINGS,
      "Cheevos帳戶" /*FIXME:"Accounts Cheevos"*/
      )
MSG_HASH(
       MENU_ENUM_LABEL_VALUE_ACCOUNTS_CHEEVOS_USERNAME,
       "用戶名"
       )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_ACCOUNTS_LIST,
      "帳戶"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_ACCOUNTS_LIST_END,
      "帳戶列表終端"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_ACCOUNTS_RETRO_ACHIEVEMENTS,
      "Retro 成就"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_ACHIEVEMENT_LIST,
      "成就列表"
      )

MSG_HASH(
      MENU_ENUM_LABEL_VALUE_ACHIEVEMENT_LIST_HARDCORE,
      "成就列表（專家模式）" /*FIXME:"Achievement List (Hardcore)"*/
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_ADD_CONTENT_LIST,
      "添加遊戲內容"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_CONFIGURATIONS_LIST,
      "設定"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_ADD_TAB,
      "導入遊戲內容"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_NETPLAY_TAB,
      "連線遊戲房間"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_ASK_ARCHIVE,
      "詢問"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_ASSETS_DIRECTORY,
       "資源目錄"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_AUDIO_BLOCK_FRAMES,
      "塊幀" /*FIXME:"Block Frames"*/
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_AUDIO_DEVICE,
       "聲音設備"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_AUDIO_DRIVER,
       "聲音驅動程式"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_AUDIO_DSP_PLUGIN,
       "聲音DSP插件"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_AUDIO_ENABLE,
      "啟用聲音"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_AUDIO_FILTER_DIR,
      "聲音過濾器目錄"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_TURBO_DEADZONE_LIST,
      "渦輪/盲區"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_AUDIO_LATENCY,
      "聲音時延(ms)"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_AUDIO_MAX_TIMING_SKEW,
      "聲音最大採樣間隔"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_AUDIO_MUTE,
      "聲音靜音"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_AUDIO_OUTPUT_RATE,
      "聲音輸出碼率(Hz)"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_AUDIO_RATE_CONTROL_DELTA,
      "動態聲音碼率控制間隔"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_AUDIO_RESAMPLER_DRIVER,
      "聲音重採樣驅動程式"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_AUDIO_SETTINGS,
      "聲音"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_AUDIO_SYNC,
      "啟用聲音同步"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_AUDIO_VOLUME,
      "聲音音量級別(dB)"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_AUTOSAVE_INTERVAL,
      "SaveRAM自動儲存間隔"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_AUTO_OVERRIDES_ENABLE,
      "自動載入覆寫文件"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_AUTO_REMAPS_ENABLE,
      "自動戴入重映射文件"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_AUTO_SHADERS_ENABLE,
      "自動戴入Shader預設"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_BASIC_MENU_CONTROLS_BACK,
      "返回"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_BASIC_MENU_CONTROLS_CONFIRM,
      "確認"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_BASIC_MENU_CONTROLS_INFO,
      "訊息"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_BASIC_MENU_CONTROLS_QUIT,
      "退出"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_BASIC_MENU_CONTROLS_SCROLL_DOWN,
      "向下滾動"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_BASIC_MENU_CONTROLS_SCROLL_UP,
      "向上滾動"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_BASIC_MENU_CONTROLS_START,
      "開始"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_BASIC_MENU_CONTROLS_TOGGLE_KEYBOARD,
      "切換鍵盤"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_BASIC_MENU_CONTROLS_TOGGLE_MENU,
      "切換選單"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_BASIC_MENU_ENUM_CONTROLS,
      "基本選單控制"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_BASIC_MENU_ENUM_CONTROLS_CONFIRM,
      "確認"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_BASIC_MENU_ENUM_CONTROLS_INFO,
      "訊息"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_BASIC_MENU_ENUM_CONTROLS_QUIT,
      "退出"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_BASIC_MENU_ENUM_CONTROLS_SCROLL_UP,
      "向上滾動"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_BASIC_MENU_ENUM_CONTROLS_START,
      "默認值"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_BASIC_MENU_ENUM_CONTROLS_TOGGLE_KEYBOARD,
      "切換鍵盤"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_BASIC_MENU_ENUM_CONTROLS_TOGGLE_MENU,
      "切換選單"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_BLOCK_SRAM_OVERWRITE,
      "載入儲存狀態時不覆蓋SaveRAM"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_BLUETOOTH_ENABLE,
      "啟用藍牙服務"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_BUILDBOT_ASSETS_URL,
      "構建機器人資源URL"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_CACHE_DIRECTORY,
      "緩沖目錄"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_CAMERA_ALLOW,
      "允許使用相機"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_CAMERA_DRIVER,
      "相機驅動程式"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_CHEAT,
      "金手指"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_CHEAT_APPLY_CHANGES,
      "執行金手指修改"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_CHEAT_DATABASE_PATH,
      "金手指文件目錄"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_CHEAT_FILE,
      "金手指文件"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_CHEAT_FILE_LOAD,
      "載入金手指文件"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_CHEAT_FILE_SAVE_AS,
      "另存金手指文件"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_CHEAT_NUM_PASSES,
      "金手指通過" /*FIXME: "Cheat Passes"*/
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_CHEEVOS_DESCRIPTION,
      "描述"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_CHEEVOS_HARDCORE_MODE_ENABLE,
/* FIXME? Translate 'Hardcore Mode' */
      "成就-專家模式"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_CHEEVOS_LOCKED_ACHIEVEMENTS,
      "已解鎖的成就:"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_CHEEVOS_LOCKED_ENTRY,
      "鎖定"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_CHEEVOS_SETTINGS,
      "Retro 成就"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_CHEEVOS_TEST_UNOFFICIAL,
/* FIXME? Translate 'Test Unofficial Achievements' */
      "非官方測試成就"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_CHEEVOS_UNLOCKED_ACHIEVEMENTS,
      "未解鎖的成就:"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_CHEEVOS_UNLOCKED_ENTRY,
      "未鎖定"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_CLOSE_CONTENT,
      "關閉"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_CONFIG,
      "設定"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_CONFIGURATIONS,
      "載入設定"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_CONFIGURATION_SETTINGS,
      "設定"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_CONFIG_SAVE_ON_EXIT,
      "退出時儲存設定"
      )
MSG_HASH(
MENU_ENUM_LABEL_VALUE_CONFIRM_ON_EXIT,
      "退出時進行詢問"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_CONTENT_COLLECTION_LIST,
      "收藏"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_CONTENT_DATABASE_DIRECTORY,
      "遊戲內容數據庫目錄"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_CONTENT_DIR,
      "遊戲內容目錄"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_CONTENT_HISTORY_SIZE,
      "歷史記錄數量")
MSG_HASH(MENU_ENUM_LABEL_VALUE_PLAYLIST_ENTRY_REMOVE,
      "允許移除記錄")
MSG_HASH(MENU_ENUM_LABEL_VALUE_CONTENT_SETTINGS,
      "快捷選單")
MSG_HASH(MENU_ENUM_LABEL_VALUE_CORE_ASSETS_DIR,
      "下載目錄")
MSG_HASH(MENU_ENUM_LABEL_VALUE_CORE_ASSETS_DIRECTORY,
      "下載目錄")
MSG_HASH(MENU_ENUM_LABEL_VALUE_CORE_CHEAT_OPTIONS,
      "金手指")
MSG_HASH(MENU_ENUM_LABEL_VALUE_CORE_COUNTERS,
      "核心計數器")
MSG_HASH(MENU_ENUM_LABEL_VALUE_CORE_ENABLE,
      "顯示核心名稱")
MSG_HASH(MENU_ENUM_LABEL_VALUE_CORE_INFORMATION,
      "核心訊息")
MSG_HASH(MENU_ENUM_LABEL_VALUE_CORE_INFO_AUTHORS,
      "作者")
MSG_HASH(MENU_ENUM_LABEL_VALUE_CORE_INFO_CATEGORIES,
      "分類")
MSG_HASH(MENU_ENUM_LABEL_VALUE_CORE_INFO_CORE_LABEL,
      "核心標籤")
MSG_HASH(MENU_ENUM_LABEL_VALUE_CORE_INFO_CORE_NAME,
      "核心名稱")
MSG_HASH(MENU_ENUM_LABEL_VALUE_CORE_INFO_FIRMWARE,
      "韌體")
MSG_HASH(MENU_ENUM_LABEL_VALUE_CORE_INFO_LICENSES,
      "許可證")
MSG_HASH(MENU_ENUM_LABEL_VALUE_CORE_INFO_PERMISSIONS,
      "許可")
MSG_HASH(MENU_ENUM_LABEL_VALUE_CORE_INFO_SUPPORTED_EXTENSIONS,
      "支持的擴展")
MSG_HASH(MENU_ENUM_LABEL_VALUE_CORE_INFO_SYSTEM_MANUFACTURER,
      "系統製造商")
MSG_HASH(MENU_ENUM_LABEL_VALUE_CORE_INFO_SYSTEM_NAME,
      "系統名稱")
MSG_HASH(MENU_ENUM_LABEL_VALUE_CORE_INPUT_REMAPPING_OPTIONS,
      "控制")
MSG_HASH(MENU_ENUM_LABEL_VALUE_CORE_LIST,
      "戴入核心")
MSG_HASH(MENU_ENUM_LABEL_VALUE_CORE_OPTIONS,
      "選項")
MSG_HASH(MENU_ENUM_LABEL_VALUE_CORE_SETTINGS,
      "核心")
MSG_HASH(MENU_ENUM_LABEL_VALUE_CORE_SET_SUPPORTS_NO_CONTENT_ENABLE,
      "自動啟動一個核心")
MSG_HASH(MENU_ENUM_LABEL_VALUE_CORE_UPDATER_AUTO_EXTRACT_ARCHIVE,
      "自動解壓下載的檔案")
MSG_HASH(MENU_ENUM_LABEL_VALUE_CORE_UPDATER_BUILDBOT_URL,
      "構建機器人核心URL")
MSG_HASH(MENU_ENUM_LABEL_VALUE_CORE_UPDATER_LIST,
      "核心更新程序")
MSG_HASH(MENU_ENUM_LABEL_VALUE_CORE_UPDATER_SETTINGS,
      "更新程序")
MSG_HASH(MENU_ENUM_LABEL_VALUE_CPU_ARCHITECTURE,
      "CPU架構:")
MSG_HASH(MENU_ENUM_LABEL_VALUE_CPU_CORES,
      "CPU核心:")
MSG_HASH(MENU_ENUM_LABEL_VALUE_CURSOR_DIRECTORY,
      "指針目錄")
MSG_HASH(MENU_ENUM_LABEL_VALUE_CURSOR_MANAGER,
      "光標管理器")
MSG_HASH(MENU_ENUM_LABEL_VALUE_CUSTOM_RATIO,
      "自定義比率")
MSG_HASH(MENU_ENUM_LABEL_VALUE_DATABASE_MANAGER,
      "數據庫管理器")
MSG_HASH(MENU_ENUM_LABEL_VALUE_DATABASE_SELECTION,
      "選擇數據庫")
MSG_HASH(MENU_ENUM_LABEL_VALUE_DELETE_ENTRY,
      "移除")
MSG_HASH(MENU_ENUM_LABEL_VALUE_FAVORITES,
      "選擇文件並探測核心") /* TODO/FIXME - update */
MSG_HASH(MENU_ENUM_LABEL_VALUE_DIRECTORY_CONTENT,
      "<遊戲內容目錄>")
MSG_HASH(MENU_ENUM_LABEL_VALUE_DIRECTORY_DEFAULT,
      "<默認>")
MSG_HASH(MENU_ENUM_LABEL_VALUE_DIRECTORY_NONE,
      "<無>")
MSG_HASH(MENU_ENUM_LABEL_VALUE_DIRECTORY_NOT_FOUND,
      "沒有找到文件夾。")
MSG_HASH(MENU_ENUM_LABEL_VALUE_DIRECTORY_SETTINGS,
      "目錄")
MSG_HASH(MENU_ENUM_LABEL_VALUE_DISK_CYCLE_TRAY_STATUS,
      "Disk Cycle Tray Status")
MSG_HASH(MENU_ENUM_LABEL_VALUE_DISK_IMAGE_APPEND,
      "追加光碟鏡像")
MSG_HASH(MENU_ENUM_LABEL_VALUE_DISK_INDEX,
      "光碟索引")
MSG_HASH(MENU_ENUM_LABEL_VALUE_DISK_OPTIONS,
      "光碟控制")
MSG_HASH(MENU_ENUM_LABEL_VALUE_DONT_CARE,
      "不關心")
MSG_HASH(MENU_ENUM_LABEL_VALUE_DOWNLOADED_FILE_DETECT_CORE_LIST,
      "下載目錄")
MSG_HASH(MENU_ENUM_LABEL_VALUE_DOWNLOAD_CORE,
      "下載核心……")
MSG_HASH(MENU_ENUM_LABEL_VALUE_DOWNLOAD_CORE_CONTENT,
      "下載遊戲內容")
MSG_HASH(MENU_ENUM_LABEL_VALUE_DPI_OVERRIDE_ENABLE,
      "啟用DPI覆蓋")
MSG_HASH(MENU_ENUM_LABEL_VALUE_DPI_OVERRIDE_VALUE,
      "DPI覆蓋")
MSG_HASH(MENU_ENUM_LABEL_VALUE_DRIVER_SETTINGS,
      "驅動")
MSG_HASH(MENU_ENUM_LABEL_VALUE_DUMMY_ON_CORE_SHUTDOWN,
/* FIXME? Translate 'Load Dummy on Core Shutdown' */
      "核心關閉時戴入虛擬程序")
MSG_HASH(MENU_ENUM_LABEL_VALUE_CHECK_FOR_MISSING_FIRMWARE,
      "載入前檢查韌體/BIOS是否存在") /*FIXME: "Check for Missing Firmware Before Loading"*/
MSG_HASH(MENU_ENUM_LABEL_VALUE_DYNAMIC_WALLPAPER,
      "動態壁紙")
MSG_HASH(MENU_ENUM_LABEL_VALUE_DYNAMIC_WALLPAPERS_DIRECTORY,
      "動態壁紙目錄")
MSG_HASH(MENU_ENUM_LABEL_VALUE_CHEEVOS_ENABLE,
/* FIXME? Translate 'Enable Achievements' */
      "啟用成就系統")
MSG_HASH(MENU_ENUM_LABEL_VALUE_ENTRY_HOVER_COLOR,
      "選單項懸停顏色")
MSG_HASH(MENU_ENUM_LABEL_VALUE_ENTRY_NORMAL_COLOR,
      "選單項正常顏色")
MSG_HASH(MENU_ENUM_LABEL_VALUE_FALSE,
      "取消")
MSG_HASH(MENU_ENUM_LABEL_VALUE_FASTFORWARD_RATIO,
      "最大運行速度")
MSG_HASH(MENU_ENUM_LABEL_VALUE_FPS_SHOW,
      "顯示幀率")
MSG_HASH(MENU_ENUM_LABEL_VALUE_FRAME_THROTTLE_ENABLE,
      "限制最大運行速度")
MSG_HASH(MENU_ENUM_LABEL_VALUE_FRAME_THROTTLE_SETTINGS,
      "幀率限制")
MSG_HASH(MENU_ENUM_LABEL_VALUE_FRONTEND_COUNTERS,
      "前端計數器")
MSG_HASH(MENU_ENUM_LABEL_VALUE_GAME_SPECIFIC_OPTIONS,
      "自動戴入遊戲內容特定的核心選項")
MSG_HASH(MENU_ENUM_LABEL_VALUE_GAME_SPECIFIC_OPTIONS_CREATE,
      "創建遊戲選項文件")
MSG_HASH(MENU_ENUM_LABEL_VALUE_GAME_SPECIFIC_OPTIONS_IN_USE,
      "遊戲選項文件")
MSG_HASH(MENU_ENUM_LABEL_VALUE_HELP,
      "幫助")
MSG_HASH(MENU_ENUM_LABEL_VALUE_HELP_AUDIO_VIDEO_TROUBLESHOOTING,
      "聲音/視訊故障排除")
MSG_HASH(MENU_ENUM_LABEL_VALUE_HELP_CHANGE_VIRTUAL_GAMEPAD,
      "變更虛擬遊戲控制器覆層")
MSG_HASH(MENU_ENUM_LABEL_VALUE_HELP_CONTROLS,
      "基本選單控制")
MSG_HASH(MENU_ENUM_LABEL_VALUE_HELP_LIST,
      "幫助")
MSG_HASH(MENU_ENUM_LABEL_VALUE_HELP_LOADING_CONTENT,
      "戴入遊戲內容")
MSG_HASH(MENU_ENUM_LABEL_VALUE_HELP_SCANNING_CONTENT,
      "掃瞄遊戲內容")
MSG_HASH(MENU_ENUM_LABEL_VALUE_HELP_WHAT_IS_A_CORE,
      "什麼是「核心」？")
MSG_HASH(MENU_ENUM_LABEL_VALUE_HISTORY_LIST_ENABLE,
      "啟用歷史記錄")
MSG_HASH(MENU_ENUM_LABEL_VALUE_HISTORY_TAB,
      "歷史")
MSG_HASH(MENU_ENUM_LABEL_VALUE_HORIZONTAL_MENU,
      "水平化選單")
MSG_HASH(MENU_ENUM_LABEL_VALUE_IMAGES_TAB,
      "圖像")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INFORMATION,
      "訊息")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INFORMATION_LIST,
      "訊息")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_ADC_TYPE,
      "手柄輸入轉數字選項")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_ALL_USERS_CONTROL_MENU,
      "所有用戶都能控制選單")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_ANALOG_LEFT_X,
      "左搖桿X")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_ANALOG_LEFT_X_MINUS,
      "左搖桿X- (左)")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_ANALOG_LEFT_X_PLUS,
      "左搖桿X+ (右)")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_ANALOG_LEFT_Y,
      "左搖桿Y")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_ANALOG_LEFT_Y_MINUS,
      "左搖桿Y- (上)")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_ANALOG_LEFT_Y_PLUS,
      "左搖桿Y+ (下)")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_ANALOG_RIGHT_X,
      "右搖桿X")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_ANALOG_RIGHT_X_MINUS,
      "右搖桿X- (左)")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_ANALOG_RIGHT_X_PLUS,
      "右搖桿X+ (右)")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_ANALOG_RIGHT_Y,
      "右搖桿Y")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_ANALOG_RIGHT_Y_MINUS,
      "右搖桿Y- (上)")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_ANALOG_RIGHT_Y_PLUS,
      "右搖桿Y+ (下)")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_LIGHTGUN_TRIGGER,
      "Gun Trigger")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_LIGHTGUN_RELOAD,
      "Gun Reload")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_LIGHTGUN_AUX_A,
      "Gun Aux A")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_LIGHTGUN_AUX_B,
      "Gun Aux B")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_LIGHTGUN_AUX_C,
      "Gun Aux C")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_LIGHTGUN_START,
      "Gun Start")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_LIGHTGUN_SELECT,
      "Gun Select")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_LIGHTGUN_DPAD_UP,
      "Gun D-pad Up")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_LIGHTGUN_DPAD_DOWN,
      "Gun D-pad Down")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_LIGHTGUN_DPAD_LEFT,
      "Gun D-pad Left")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_LIGHTGUN_DPAD_RIGHT,
      "Gun D-pad Right")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_AUTODETECT_ENABLE,
      "啟用自動設定")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_AXIS_THRESHOLD,
      "輸入軸閾值")
MSG_HASH(MENU_ENUM_LABEL_VALUE_MENU_INPUT_SWAP_OK_CANCEL,
      "選單切換 確定/取消 按鈕") /*FIXME:"Menu Swap OK & Cancel Buttons"*/
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_BIND_ALL,
      "綁定全部")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_BIND_DEFAULT_ALL,
      "綁定全部至默認值")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_BIND_TIMEOUT,
      "綁定超時時間")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_DESCRIPTOR_HIDE_UNBOUND,
      "隱藏未綁定的核心輸入描述")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_DESCRIPTOR_LABEL_SHOW,
      "顯示輸入描述標籤")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_DEVICE_INDEX,
      "設備索引")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_DEVICE_TYPE,
      "設備類型")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_DRIVER,
      "輸入驅動")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_DUTY_CYCLE,
      "Turbo占空比")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_HOTKEY_BINDS,
      "輸入熱鍵綁定")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_ICADE_ENABLE,
      "鍵盤控制器映射啟用")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_JOYPAD_A,
      "A鍵(右側)")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_JOYPAD_B,
      "B鍵(下方)")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_JOYPAD_DOWN,
      "下十字鍵")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_JOYPAD_L2,
      "L2鍵(觸發)")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_JOYPAD_L3,
      "L3鍵(拇指)")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_JOYPAD_L,
      "L鍵(手柄肩部)")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_JOYPAD_LEFT,
      "左十字鍵")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_JOYPAD_R2,
      "R2鍵(觸發)")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_JOYPAD_R3,
      "R3鍵(拇指)")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_JOYPAD_R,
      "R鍵(手柄肩部)")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_JOYPAD_RIGHT,
      "右十字鍵")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_JOYPAD_SELECT,
      "選擇鍵")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_JOYPAD_START,
      "開始鍵")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_JOYPAD_UP,
      "上十字鍵")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_JOYPAD_X,
      "X鍵(上方)")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_JOYPAD_Y,
      "Y鍵(左側)")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_KEY,
      "(鍵: %s)") /*FIXME:"(Key: %s)"*/
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_MOUSE_LEFT,
      "Mouse 1")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_MOUSE_RIGHT,
      "Mouse 2")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_MOUSE_MIDDLE,
      "Mouse 3")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_MOUSE_BUTTON4,
      "Mouse 4")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_MOUSE_BUTTON5,
      "Mouse 5")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_MOUSE_WHEEL_UP,
      "Wheel Up")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_MOUSE_WHEEL_DOWN,
      "Wheel Down")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_MOUSE_HORIZ_WHEEL_UP,
      "Wheel Left")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_MOUSE_HORIZ_WHEEL_DOWN,
      "Wheel Right")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_KEYBOARD_GAMEPAD_MAPPING_TYPE,
      "鍵盤控制器映射類型")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_MAX_USERS,
      "最大用戶數")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_MENU_ENUM_TOGGLE_GAMEPAD_COMBO,
      "遊戲控制器選單切出組合鍵")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_META_CHEAT_INDEX_MINUS,
      "金手指索引 -")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_META_CHEAT_INDEX_PLUS,
      "金手指索引 +")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_META_CHEAT_TOGGLE,
      "金手指開關")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_META_DISK_EJECT_TOGGLE,
      "光驅出倉切換")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_META_DISK_NEXT,
      "下一張光碟")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_META_DISK_PREV,
      "上一張光碟")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_META_ENABLE_HOTKEY,
      "啟用熱鍵")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_META_FAST_FORWARD_HOLD_KEY,
      "快進保持")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_META_FAST_FORWARD_KEY,
      "快進切換")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_META_FRAMEADVANCE,
      "幀提前量")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_META_FULLSCREEN_TOGGLE_KEY,
      "切換全營幕")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_META_GRAB_MOUSE_TOGGLE,
      "鼠標捕獲開關")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_META_GAME_FOCUS_TOGGLE,
      "切換遊戲焦距")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_META_LOAD_STATE_KEY,
      "戴入狀態")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_META_MENU_TOGGLE,
      "切換選單")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_META_MOVIE_RECORD_TOGGLE,
      "視訊錄製開關")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_META_MUTE,
      "靜音開關")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_META_NETPLAY_GAME_WATCH,
      "連線遊戲切換 遊戲/圍觀 模式")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_META_OSK,
      "切換營幕鍵盤")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_META_OVERLAY_NEXT,
      "下一個覆層")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_META_PAUSE_TOGGLE,
      "切換暫停")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_META_QUIT_KEY,
      "退出 RetroArch")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_META_RESET,
      "重置遊戲")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_META_REWIND,
      "回溯")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_META_SAVE_STATE_KEY,
      "儲存狀態")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_META_SCREENSHOT,
      "營幕截圖")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_META_SHADER_NEXT,
      "下一個Shader")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_META_SHADER_PREV,
      "上一個Shader")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_META_SLOWMOTION_HOLD_KEY,
      "慢動作")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_META_STATE_SLOT_MINUS,
      "存檔槽 -")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_META_STATE_SLOT_PLUS,
      "存檔槽 +")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_META_VOLUME_DOWN,
      "音量 -")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_META_VOLUME_UP,
      "音量 +")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_OSK_OVERLAY_ENABLE,
      "顯示鍵盤覆層")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_OVERLAY_ENABLE,
      "顯示覆層")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_OVERLAY_HIDE_IN_MENU,
      "在選單中隱藏覆層")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_POLL_TYPE_BEHAVIOR,
      "輪詢類型行為")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_POLL_TYPE_BEHAVIOR_EARLY,
      "較早")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_POLL_TYPE_BEHAVIOR_LATE,
      "稍晚")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_POLL_TYPE_BEHAVIOR_NORMAL,
      "正常")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_PREFER_FRONT_TOUCH,
      "優先前置觸摸")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_REMAPPING_DIRECTORY,
      "輸入重映射目錄")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_REMAP_BINDS_ENABLE,
      "啟用綁定重映射")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_SAVE_AUTOCONFIG,
      "儲存自動設定")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_SETTINGS,
      "輸入")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_SMALL_KEYBOARD_ENABLE,
      "啟用小鍵盤")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_TOUCH_ENABLE,
      "啟用觸摸")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_TURBO_ENABLE,
      "TURBO開關")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_TURBO_PERIOD,
      "Turbo區間")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_USER_BINDS,
      "輸入用戶 %u 的綁定")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INTERNAL_STORAGE_STATUS,
      "內部存儲狀態")
MSG_HASH(MENU_ENUM_LABEL_VALUE_JOYPAD_AUTOCONFIG_DIR,
      "輸入設備自動設定目錄")
MSG_HASH(MENU_ENUM_LABEL_VALUE_JOYPAD_DRIVER,
      "手柄驅動")
MSG_HASH(MENU_ENUM_LABEL_VALUE_LAKKA_SERVICES,
      "Lakka 服務")
MSG_HASH(MENU_ENUM_LABEL_VALUE_LANG_CHINESE_SIMPLIFIED,
      "簡體中文")
MSG_HASH(MENU_ENUM_LABEL_VALUE_LANG_CHINESE_TRADITIONAL,
      "繁體中文")
MSG_HASH(MENU_ENUM_LABEL_VALUE_LANG_DUTCH,
      "荷蘭語")
MSG_HASH(MENU_ENUM_LABEL_VALUE_LANG_ENGLISH,
      "英語")
MSG_HASH(MENU_ENUM_LABEL_VALUE_LANG_ESPERANTO,
      "世界語")
MSG_HASH(MENU_ENUM_LABEL_VALUE_LANG_FRENCH,
      "法語")
MSG_HASH(MENU_ENUM_LABEL_VALUE_LANG_GERMAN,
      "德語")
MSG_HASH(MENU_ENUM_LABEL_VALUE_LANG_ITALIAN,
      "意大利語")
MSG_HASH(MENU_ENUM_LABEL_VALUE_LANG_JAPANESE,
      "日語")
MSG_HASH(MENU_ENUM_LABEL_VALUE_LANG_KOREAN,
      "韓語")
MSG_HASH(MENU_ENUM_LABEL_VALUE_LANG_POLISH,
      "波蘭語")
MSG_HASH(MENU_ENUM_LABEL_VALUE_LANG_PORTUGUESE_BRAZIL,
      "葡萄牙語")
MSG_HASH(MENU_ENUM_LABEL_VALUE_LANG_PORTUGUESE_PORTUGAL,
      "葡萄牙語")
MSG_HASH(MENU_ENUM_LABEL_VALUE_LANG_RUSSIAN,
      "俄語")
MSG_HASH(MENU_ENUM_LABEL_VALUE_LANG_SPANISH,
      "西班牙語")
MSG_HASH(MENU_ENUM_LABEL_VALUE_LANG_VIETNAMESE,
      "越南語")
MSG_HASH(MENU_ENUM_LABEL_VALUE_LANG_ARABIC,
      "Arabic")
MSG_HASH(MENU_ENUM_LABEL_VALUE_LEFT_ANALOG,
      "左側搖桿")
MSG_HASH(MENU_ENUM_LABEL_VALUE_LIBRETRO_DIR_PATH,
      "核心目錄")
MSG_HASH(MENU_ENUM_LABEL_VALUE_LIBRETRO_INFO_PATH,
      "核心訊息目錄")
MSG_HASH(MENU_ENUM_LABEL_VALUE_LIBRETRO_LOG_LEVEL,
      "核心日誌級別")
MSG_HASH(MENU_ENUM_LABEL_VALUE_LINEAR,
      "線性")
MSG_HASH(MENU_ENUM_LABEL_VALUE_LOAD_ARCHIVE,
      "使用核心戴入壓縮包")
MSG_HASH(MENU_ENUM_LABEL_VALUE_LOAD_CONTENT_HISTORY,
      "戴入最近的遊戲內容")
MSG_HASH(MENU_ENUM_LABEL_VALUE_LOAD_CONTENT_LIST,
      "載入遊戲內容")
MSG_HASH(MENU_ENUM_LABEL_VALUE_LOAD_STATE,
      "戴入狀態")
MSG_HASH(MENU_ENUM_LABEL_VALUE_LOCATION_ALLOW,
      "允許使用位置")
MSG_HASH(MENU_ENUM_LABEL_VALUE_LOCATION_DRIVER,
      "定位驅動")
MSG_HASH(MENU_ENUM_LABEL_VALUE_LOGGING_SETTINGS,
      "日誌")
MSG_HASH(MENU_ENUM_LABEL_VALUE_LOG_VERBOSITY,
      "完整日誌記錄")
MSG_HASH(MENU_ENUM_LABEL_VALUE_MAIN_MENU,
      "主選單")
MSG_HASH(MENU_ENUM_LABEL_VALUE_MANAGEMENT,
      "數據庫設定")
MSG_HASH(MENU_ENUM_LABEL_VALUE_MATERIALUI_MENU_COLOR_THEME,
      "選單顏色主題")
MSG_HASH(MENU_ENUM_LABEL_VALUE_MATERIALUI_MENU_COLOR_THEME_BLUE,
      "藍色")
MSG_HASH(MENU_ENUM_LABEL_VALUE_MATERIALUI_MENU_COLOR_THEME_BLUE_GREY,
      "藍灰色")
MSG_HASH(MENU_ENUM_LABEL_VALUE_MATERIALUI_MENU_COLOR_THEME_DARK_BLUE,
      "深藍色")
MSG_HASH(MENU_ENUM_LABEL_VALUE_MATERIALUI_MENU_COLOR_THEME_GREEN,
      "綠色")
MSG_HASH(MENU_ENUM_LABEL_VALUE_MATERIALUI_MENU_COLOR_THEME_NVIDIA_SHIELD,
      "NV SHIELD")
MSG_HASH(MENU_ENUM_LABEL_VALUE_MATERIALUI_MENU_COLOR_THEME_RED,
      "紅色")
MSG_HASH(MENU_ENUM_LABEL_VALUE_MATERIALUI_MENU_COLOR_THEME_YELLOW,
      "黃色")
MSG_HASH(MENU_ENUM_LABEL_VALUE_MATERIALUI_MENU_FOOTER_OPACITY,
      "底部不透明度")
MSG_HASH(MENU_ENUM_LABEL_VALUE_MATERIALUI_MENU_HEADER_OPACITY,
      "頂部不透明度")
MSG_HASH(MENU_ENUM_LABEL_VALUE_MENU_DRIVER,
      "選單驅動")
MSG_HASH(MENU_ENUM_LABEL_VALUE_MENU_ENUM_THROTTLE_FRAMERATE,
      "限制選單幀率")
MSG_HASH(MENU_ENUM_LABEL_VALUE_MENU_FILE_BROWSER_SETTINGS, /* TODO/FIXME - update */
      "選單文件瀏覽器")
MSG_HASH(MENU_ENUM_LABEL_VALUE_MENU_LINEAR_FILTER,
      "選單線性過濾")
MSG_HASH(MENU_ENUM_LABEL_VALUE_MENU_SETTINGS,
      "選單")
MSG_HASH(MENU_ENUM_LABEL_VALUE_MENU_WALLPAPER,
      "選單壁紙")
MSG_HASH(MENU_ENUM_LABEL_VALUE_MENU_WALLPAPER_OPACITY,
      "壁紙不透明度")
MSG_HASH(MENU_ENUM_LABEL_VALUE_MISSING,
      "丟失")
MSG_HASH(MENU_ENUM_LABEL_VALUE_MORE,
      "...")
MSG_HASH(MENU_ENUM_LABEL_VALUE_MOUSE_ENABLE,
      "鼠標支持")
MSG_HASH(MENU_ENUM_LABEL_VALUE_MULTIMEDIA_SETTINGS,
      "多媒體")
MSG_HASH(MENU_ENUM_LABEL_VALUE_MUSIC_TAB,
      "音樂")
MSG_HASH(MENU_ENUM_LABEL_VALUE_NAVIGATION_BROWSER_FILTER_SUPPORTED_EXTENSIONS_ENABLE,
      "過濾未知擴展名")
MSG_HASH(MENU_ENUM_LABEL_VALUE_NAVIGATION_WRAPAROUND,
      "環繞式導航")
MSG_HASH(MENU_ENUM_LABEL_VALUE_NEAREST,
      "最近")
MSG_HASH(MENU_ENUM_LABEL_VALUE_NETPLAY,
      "連線遊戲")
MSG_HASH(MENU_ENUM_LABEL_VALUE_NETPLAY_CHECK_FRAMES,
      "連線遊戲檢查幀數")
MSG_HASH(MENU_ENUM_LABEL_VALUE_NETPLAY_DELAY_FRAMES,
      "連線遊戲延遲幀數")
MSG_HASH(MENU_ENUM_LABEL_VALUE_NETPLAY_DISCONNECT,
      "斷開連接")
MSG_HASH(MENU_ENUM_LABEL_VALUE_NETPLAY_ENABLE,
      "啟用連線遊戲")
MSG_HASH(MENU_ENUM_LABEL_VALUE_NETPLAY_ENABLE_CLIENT,
      "連接到遊戲主機")
MSG_HASH(MENU_ENUM_LABEL_VALUE_NETPLAY_ENABLE_HOST,
      "作為遊戲主機")
MSG_HASH(MENU_ENUM_LABEL_VALUE_NETPLAY_DISABLE_HOST,
      "停止連線主機")
MSG_HASH(MENU_ENUM_LABEL_VALUE_NETPLAY_IP_ADDRESS,
      "服務器地址")
MSG_HASH(MENU_ENUM_LABEL_VALUE_NETPLAY_LAN_SCAN_SETTINGS,
      "掃瞄本地網路")
MSG_HASH(MENU_ENUM_LABEL_VALUE_NETPLAY_MODE,
      "啟用連線遊戲客戶端")
MSG_HASH(MENU_ENUM_LABEL_VALUE_NETPLAY_NICKNAME,
      "用戶名")
MSG_HASH(MENU_ENUM_LABEL_VALUE_NETPLAY_PASSWORD,
      "服務器密碼")
MSG_HASH(MENU_ENUM_LABEL_VALUE_NETPLAY_SETTINGS,
      "連線遊戲設定")
MSG_HASH(MENU_ENUM_LABEL_VALUE_NETPLAY_STATELESS_MODE,
      "連線遊戲無狀態模式")
MSG_HASH(MENU_ENUM_LABEL_VALUE_NETPLAY_SPECTATE_PASSWORD,
      "服務器圍觀的密碼")
MSG_HASH(MENU_ENUM_LABEL_VALUE_NETPLAY_SPECTATOR_MODE_ENABLE,
      "啟用連線遊戲旁觀者")
MSG_HASH(MENU_ENUM_LABEL_VALUE_NETPLAY_TCP_UDP_PORT,
      "連線遊戲TCP/UDP端口")
MSG_HASH(MENU_ENUM_LABEL_VALUE_NETPLAY_NAT_TRAVERSAL,
      "連線遊戲使用NAT穿透技術")
MSG_HASH(MENU_ENUM_LABEL_VALUE_NETWORK_CMD_ENABLE,
      "網路命令")
MSG_HASH(MENU_ENUM_LABEL_VALUE_NETWORK_CMD_PORT,
      "網路命令端口")
MSG_HASH(MENU_ENUM_LABEL_VALUE_NETWORK_INFORMATION,
      "網路訊息")
MSG_HASH(MENU_ENUM_LABEL_VALUE_NETWORK_REMOTE_ENABLE,
      "網路遊戲控制器")
MSG_HASH(MENU_ENUM_LABEL_VALUE_NETWORK_REMOTE_PORT,
      "網路遠端基本端口")
MSG_HASH(MENU_ENUM_LABEL_VALUE_NETWORK_SETTINGS,
      "網路")
MSG_HASH(MENU_ENUM_LABEL_VALUE_NO,
      "否")
MSG_HASH(MENU_ENUM_LABEL_VALUE_NONE,
      "無")
MSG_HASH(MENU_ENUM_LABEL_VALUE_NOT_AVAILABLE,
      "N/A")
MSG_HASH(MENU_ENUM_LABEL_VALUE_NO_ACHIEVEMENTS_TO_DISPLAY,
      "沒有可顯示的成就。")
MSG_HASH(MENU_ENUM_LABEL_VALUE_NO_CORE,
      "沒有核心")
MSG_HASH(MENU_ENUM_LABEL_VALUE_NO_CORES_AVAILABLE,
      "沒有可用的核心。")
MSG_HASH(MENU_ENUM_LABEL_VALUE_NO_CORE_INFORMATION_AVAILABLE,
      "沒有可用的核心訊息。")
MSG_HASH(MENU_ENUM_LABEL_VALUE_NO_CORE_OPTIONS_AVAILABLE,
      "沒有可用的核心選項。")
MSG_HASH(MENU_ENUM_LABEL_VALUE_NO_ENTRIES_TO_DISPLAY,
      "沒有可顯示的條目。")
MSG_HASH(MENU_ENUM_LABEL_VALUE_NO_HISTORY_AVAILABLE,
      "沒有可用的歷史記錄。")
MSG_HASH(MENU_ENUM_LABEL_VALUE_NO_INFORMATION_AVAILABLE,
      "沒有可用的訊息。")
MSG_HASH(MENU_ENUM_LABEL_VALUE_NO_ITEMS,
      "沒有條目。")
MSG_HASH(MENU_ENUM_LABEL_VALUE_NO_NETPLAY_HOSTS_FOUND,
      "未發現連線遊戲主機。")
MSG_HASH(MENU_ENUM_LABEL_VALUE_NO_NETWORKS_FOUND,
      "未發現網路。")
MSG_HASH(MENU_ENUM_LABEL_VALUE_NO_PERFORMANCE_COUNTERS,
      "沒有性能計數器。")
MSG_HASH(MENU_ENUM_LABEL_VALUE_NO_PLAYLISTS,
      "沒有遊戲列表。")
MSG_HASH(MENU_ENUM_LABEL_VALUE_NO_PLAYLIST_ENTRIES_AVAILABLE,
      "沒有可用的遊戲列表項目。")
MSG_HASH(MENU_ENUM_LABEL_VALUE_NO_SETTINGS_FOUND,
      "沒有找到設定。")
MSG_HASH(MENU_ENUM_LABEL_VALUE_NO_SHADER_PARAMETERS,
      "沒有Shader參數.")
MSG_HASH(MENU_ENUM_LABEL_VALUE_OFF,
      "關")
MSG_HASH(MENU_ENUM_LABEL_VALUE_ON,
      "開")
MSG_HASH(MENU_ENUM_LABEL_VALUE_ONLINE_UPDATER,
      "連線更新器")
MSG_HASH(MENU_ENUM_LABEL_VALUE_ONSCREEN_DISPLAY_SETTINGS,
      "營幕顯示")
MSG_HASH(MENU_ENUM_LABEL_VALUE_ONSCREEN_OVERLAY_SETTINGS,
      "營幕覆層")
MSG_HASH(MENU_ENUM_LABEL_VALUE_OPEN_ARCHIVE,
      "以文件夾形式打開壓縮包")
MSG_HASH(MENU_ENUM_LABEL_VALUE_ONSCREEN_NOTIFICATIONS_SETTINGS,
      "營幕通知")
MSG_HASH(MENU_ENUM_LABEL_VALUE_OPTIONAL,
      "任意")
MSG_HASH(MENU_ENUM_LABEL_VALUE_OSK_OVERLAY_DIRECTORY,
      "OSK覆層目錄")
MSG_HASH(MENU_ENUM_LABEL_VALUE_OVERLAY,
      "覆層")
MSG_HASH(MENU_ENUM_LABEL_VALUE_OVERLAY_AUTOLOAD_PREFERRED,
      "自動戴入最佳的覆層")
MSG_HASH(MENU_ENUM_LABEL_VALUE_OVERLAY_DIRECTORY,
      "覆層目錄")
MSG_HASH(MENU_ENUM_LABEL_VALUE_OVERLAY_OPACITY,
      "覆層不透明度")
MSG_HASH(MENU_ENUM_LABEL_VALUE_OVERLAY_PRESET,
      "覆層預設")
MSG_HASH(MENU_ENUM_LABEL_VALUE_OVERLAY_SCALE,
      "覆層縮放比例")
MSG_HASH(MENU_ENUM_LABEL_VALUE_OVERLAY_SETTINGS,
      "營幕覆層")
MSG_HASH(MENU_ENUM_LABEL_VALUE_PAL60_ENABLE,
      "使用PAL60模式")
MSG_HASH(MENU_ENUM_LABEL_VALUE_PARENT_DIRECTORY,
      "上一級目錄")
MSG_HASH(MENU_ENUM_LABEL_VALUE_PAUSE_LIBRETRO,
      "當選單激活時暫停")
MSG_HASH(MENU_ENUM_LABEL_VALUE_PAUSE_NONACTIVE,
      "禁止後台運行")
MSG_HASH(MENU_ENUM_LABEL_VALUE_PERFCNT_ENABLE,
      "性能計數器")
MSG_HASH(MENU_ENUM_LABEL_VALUE_PLAYLISTS_TAB,
      "遊戲列表")
MSG_HASH(MENU_ENUM_LABEL_VALUE_PLAYLIST_DIRECTORY,
      "遊戲列表目錄")
MSG_HASH(MENU_ENUM_LABEL_VALUE_PLAYLIST_SETTINGS,
      "遊戲列表")
MSG_HASH(MENU_ENUM_LABEL_VALUE_POINTER_ENABLE,
      "觸控支援")
MSG_HASH(MENU_ENUM_LABEL_VALUE_PORT,
      "端口")
MSG_HASH(MENU_ENUM_LABEL_VALUE_PRESENT,
      "現在")
MSG_HASH(MENU_ENUM_LABEL_VALUE_PRIVACY_SETTINGS,
      "隱私")
MSG_HASH(MENU_ENUM_LABEL_VALUE_QUIT_RETROARCH,
      "退出 RetroArch")
MSG_HASH(MENU_ENUM_LABEL_VALUE_RDB_ENTRY_ANALOG,
      "支持搖桿輸入")
MSG_HASH(MENU_ENUM_LABEL_VALUE_RDB_ENTRY_BBFC_RATING,
      "BBFC 分級")
MSG_HASH(MENU_ENUM_LABEL_VALUE_RDB_ENTRY_CERO_RATING,
      "CERO 分級")
MSG_HASH(MENU_ENUM_LABEL_VALUE_RDB_ENTRY_COOP,
      "多人遊戲支持")
MSG_HASH(MENU_ENUM_LABEL_VALUE_RDB_ENTRY_CRC32,
      "CRC32")
MSG_HASH(MENU_ENUM_LABEL_VALUE_RDB_ENTRY_DESCRIPTION,
      "描述")
MSG_HASH(MENU_ENUM_LABEL_VALUE_RDB_ENTRY_DEVELOPER,
      "開發者")
MSG_HASH(MENU_ENUM_LABEL_VALUE_RDB_ENTRY_EDGE_MAGAZINE_ISSUE,
      "Edge雜誌發行")
MSG_HASH(MENU_ENUM_LABEL_VALUE_RDB_ENTRY_EDGE_MAGAZINE_RATING,
      "Edge雜誌評分")
MSG_HASH(MENU_ENUM_LABEL_VALUE_RDB_ENTRY_EDGE_MAGAZINE_REVIEW,
      "Edge雜誌評論")
MSG_HASH(MENU_ENUM_LABEL_VALUE_RDB_ENTRY_ELSPA_RATING,
      "ELSPA 分級")
MSG_HASH(MENU_ENUM_LABEL_VALUE_RDB_ENTRY_ENHANCEMENT_HW,
      "增強硬件")
MSG_HASH(MENU_ENUM_LABEL_VALUE_RDB_ENTRY_ESRB_RATING,
      "ESRB 分級")
MSG_HASH(MENU_ENUM_LABEL_VALUE_RDB_ENTRY_FAMITSU_MAGAZINE_RATING,
      "次世代(Famitsu)雜誌評分")
MSG_HASH(MENU_ENUM_LABEL_VALUE_RDB_ENTRY_FRANCHISE,
      "經銷商")
MSG_HASH(MENU_ENUM_LABEL_VALUE_RDB_ENTRY_GENRE,
      "類型")
MSG_HASH(MENU_ENUM_LABEL_VALUE_RDB_ENTRY_MD5,
      "MD5")
MSG_HASH(MENU_ENUM_LABEL_VALUE_RDB_ENTRY_NAME,
      "名稱")
MSG_HASH(MENU_ENUM_LABEL_VALUE_RDB_ENTRY_ORIGIN,
      "起源")
MSG_HASH(MENU_ENUM_LABEL_VALUE_RDB_ENTRY_PEGI_RATING,
      "PEGI 分級")
MSG_HASH(MENU_ENUM_LABEL_VALUE_RDB_ENTRY_PUBLISHER,
      "出版方")
MSG_HASH(MENU_ENUM_LABEL_VALUE_RDB_ENTRY_RELEASE_MONTH,
      "發售月份")
MSG_HASH(MENU_ENUM_LABEL_VALUE_RDB_ENTRY_RELEASE_YEAR,
      "發售年份")
MSG_HASH(MENU_ENUM_LABEL_VALUE_RDB_ENTRY_RUMBLE,
      "震動支持")
MSG_HASH(MENU_ENUM_LABEL_VALUE_RDB_ENTRY_SERIAL,
      "系列")
MSG_HASH(MENU_ENUM_LABEL_VALUE_RDB_ENTRY_SHA1,
      "SHA1")
MSG_HASH(MENU_ENUM_LABEL_VALUE_RDB_ENTRY_START_CONTENT,
      "啟動遊戲內容")
MSG_HASH(MENU_ENUM_LABEL_VALUE_RDB_ENTRY_TGDB_RATING,
      "TGDB 評分")
MSG_HASH(MENU_ENUM_LABEL_VALUE_REBOOT,
      "重啟")
MSG_HASH(MENU_ENUM_LABEL_VALUE_RECORDING_CONFIG_DIRECTORY,
      "錄影設定目錄")
MSG_HASH(MENU_ENUM_LABEL_VALUE_RECORDING_OUTPUT_DIRECTORY,
      "錄影輸出目錄")
MSG_HASH(MENU_ENUM_LABEL_VALUE_RECORDING_SETTINGS,
      "錄影")
MSG_HASH(MENU_ENUM_LABEL_VALUE_RECORD_CONFIG,
      "錄影設定")
MSG_HASH(MENU_ENUM_LABEL_VALUE_RECORD_DRIVER,
      "錄影驅動")
MSG_HASH(MENU_ENUM_LABEL_VALUE_RECORD_ENABLE,
      "啟用錄影")
MSG_HASH(MENU_ENUM_LABEL_VALUE_RECORD_PATH,
      "輸出文件")
MSG_HASH(MENU_ENUM_LABEL_VALUE_RECORD_USE_OUTPUT_DIRECTORY,
      "使用輸出目錄")
MSG_HASH(MENU_ENUM_LABEL_VALUE_REMAP_FILE,
      "重映射文件")
MSG_HASH(MENU_ENUM_LABEL_VALUE_REMAP_FILE_LOAD,
      "戴入重映射文件")
MSG_HASH(MENU_ENUM_LABEL_VALUE_REMAP_FILE_SAVE_CORE,
      "儲存核心重映射文件")
MSG_HASH(MENU_ENUM_LABEL_VALUE_REMAP_FILE_SAVE_GAME,
      "儲存遊戲重映射文件")
MSG_HASH(MENU_ENUM_LABEL_VALUE_REQUIRED,
      "必須")
MSG_HASH(MENU_ENUM_LABEL_VALUE_RESTART_CONTENT,
      "重啟")
MSG_HASH(MENU_ENUM_LABEL_VALUE_RESTART_RETROARCH,
      "重啟 RetroArch")
MSG_HASH(MENU_ENUM_LABEL_VALUE_RESUME,
      "繼續")
MSG_HASH(MENU_ENUM_LABEL_VALUE_RESUME_CONTENT,
      "繼續")
MSG_HASH(MENU_ENUM_LABEL_VALUE_RETROKEYBOARD,
      "Retro鍵盤")
MSG_HASH(MENU_ENUM_LABEL_VALUE_RETROPAD,
      "Retro觸控板")
MSG_HASH(MENU_ENUM_LABEL_VALUE_RETROPAD_WITH_ANALOG,
      "RetroPad w/ Analog")
MSG_HASH(MENU_ENUM_LABEL_VALUE_RETRO_ACHIEVEMENTS_SETTINGS,
      "Retro 成就")
MSG_HASH(MENU_ENUM_LABEL_VALUE_REWIND_ENABLE,
      "啟用回溯")
MSG_HASH(MENU_ENUM_LABEL_VALUE_REWIND_GRANULARITY,
      "回溯粒度")
MSG_HASH(MENU_ENUM_LABEL_VALUE_REWIND_SETTINGS,
      "回溯")
MSG_HASH(MENU_ENUM_LABEL_VALUE_RGUI_BROWSER_DIRECTORY,
      "文件瀏覽器目錄")
MSG_HASH(MENU_ENUM_LABEL_VALUE_RGUI_CONFIG_DIRECTORY,
      "設定目錄")
MSG_HASH(MENU_ENUM_LABEL_VALUE_RGUI_SHOW_START_SCREEN,
      "顯示開始營幕")
MSG_HASH(MENU_ENUM_LABEL_VALUE_RIGHT_ANALOG,
      "右側搖桿")
MSG_HASH(MENU_ENUM_LABEL_VALUE_RUN,
      "運行")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SAMBA_ENABLE,
      "啟用SAMBA文件共享服務")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SAVEFILE_DIRECTORY,
      "存檔文件目錄")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SAVESTATE_AUTO_INDEX,
      "自動索引儲存狀態")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SAVESTATE_AUTO_LOAD,
      "自動戴入狀態")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SAVESTATE_AUTO_SAVE,
      "自動儲存狀態")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SAVESTATE_DIRECTORY,
      "狀態存儲目錄")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SAVESTATE_THUMBNAIL_ENABLE,
      "既時存檔縮圖")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SAVE_CURRENT_CONFIG,
      "儲存當前設定")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SAVE_CURRENT_CONFIG_OVERRIDE_CORE,
      "儲存核心覆寫")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SAVE_CURRENT_CONFIG_OVERRIDE_GAME,
      "儲存遊戲覆寫")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SAVE_NEW_CONFIG,
      "儲存新設定")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SAVE_STATE,
      "儲存狀態")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SAVING_SETTINGS,
      "存檔")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SCAN_DIRECTORY,
      "掃瞄文件夾")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SCAN_FILE,
      "掃瞄文件")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SCAN_THIS_DIRECTORY,
      "<掃瞄當前目錄>")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SCREENSHOT_DIRECTORY,
      "營幕截圖目錄")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SCREEN_RESOLUTION,
      "營幕分辨率")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SEARCH,
      "搜索：")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SECONDS,
      "秒")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SETTINGS,
      "設定")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SETTINGS_TAB,
      "設定")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SHADER,
      "Shader")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SHADER_APPLY_CHANGES,
      "應用Shader修改")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SHADER_OPTIONS,
      "Shader效果")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SHADER_PIPELINE_RIBBON,
      "Ribbon")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SHADER_PIPELINE_RIBBON_SIMPLIFIED,
      "Ribbon (簡化)")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SHADER_PIPELINE_SIMPLE_SNOW,
      "Simple Snow")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SHADER_PIPELINE_SNOW,
      "Snow")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SHOW_ADVANCED_SETTINGS,
      "顯示高級設定")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SHOW_HIDDEN_FILES,
      "顯示隱藏的文件和文件夾")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SHUTDOWN,
      "關機")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SLOWMOTION_RATIO,
      "慢動作倍率")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SORT_SAVEFILES_ENABLE,
      "排序文件夾中的存檔")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SORT_SAVESTATES_ENABLE,
      "排序文件夾中的狀態存儲")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SSH_ENABLE,
      "啟用SSH遠程終端服務")
MSG_HASH(MENU_ENUM_LABEL_VALUE_START_CORE,
      "啟動核心")
MSG_HASH(MENU_ENUM_LABEL_VALUE_START_NET_RETROPAD,
      "啟動遠程的RetroPad")
MSG_HASH(MENU_ENUM_LABEL_VALUE_START_VIDEO_PROCESSOR,
      "啟動視訊處理")
MSG_HASH(MENU_ENUM_LABEL_VALUE_STATE_SLOT,
      "狀態存儲槽")
MSG_HASH(MENU_ENUM_LABEL_VALUE_STATUS,
      "狀態")
MSG_HASH(MENU_ENUM_LABEL_VALUE_STDIN_CMD_ENABLE,
      "標準輸入流命令")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SUPPORTED_CORES,
      "支持的核心")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SUSPEND_SCREENSAVER_ENABLE,
      "暫停屏保程序")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SYSTEM_BGM_ENABLE,
      "啟用系統背景音樂")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SYSTEM_DIRECTORY,
      "系統/BIOS目錄")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SYSTEM_INFORMATION,
      "系統訊息")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SYSTEM_INFO_7ZIP_SUPPORT,
      "7zip 支持")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SYSTEM_INFO_ALSA_SUPPORT,
      "ALSA 支持")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SYSTEM_INFO_BUILD_DATE,
      "編譯日期")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SYSTEM_INFO_CG_SUPPORT,
      "Cg 支持")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SYSTEM_INFO_COCOA_SUPPORT,
      "Cocoa 支持")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SYSTEM_INFO_COMMAND_IFACE_SUPPORT,
      "控制台支持")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SYSTEM_INFO_CORETEXT_SUPPORT,
      "CoreText 支持")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SYSTEM_INFO_CPU_FEATURES,
      "CPU特性")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SYSTEM_INFO_DISPLAY_METRIC_DPI,
      "顯示器度量DPI")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SYSTEM_INFO_DISPLAY_METRIC_MM_HEIGHT,
      "顯示器度量高度(mm)")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SYSTEM_INFO_DISPLAY_METRIC_MM_WIDTH,
      "顯示器度量寬度(mm)")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SYSTEM_INFO_DSOUND_SUPPORT,
      "DirectSound 支持")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SYSTEM_INFO_WASAPI_SUPPORT,
      "WASAPI 支持")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SYSTEM_INFO_DYLIB_SUPPORT,
      "動態鏈接庫支持")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SYSTEM_INFO_DYNAMIC_SUPPORT,
      "運行時動態戴入libretro庫")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SYSTEM_INFO_EGL_SUPPORT,
      "EGL 支持")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SYSTEM_INFO_FBO_SUPPORT,
      "OpenGL/Direct3D 渲染至紋理 (多渲染批次Shader) 支持")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SYSTEM_INFO_FFMPEG_SUPPORT,
      "FFmpeg 支持")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SYSTEM_INFO_FREETYPE_SUPPORT,
      "FreeType 支持")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SYSTEM_INFO_FRONTEND_IDENTIFIER,
      "前端標識")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SYSTEM_INFO_FRONTEND_NAME,
      "前端名稱")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SYSTEM_INFO_FRONTEND_OS,
      "前端操作系統")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SYSTEM_INFO_GIT_VERSION,
      "Git版本")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SYSTEM_INFO_GLSL_SUPPORT,
      "GLSL 支持")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SYSTEM_INFO_HLSL_SUPPORT,
      "HLSL 支持")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SYSTEM_INFO_JACK_SUPPORT,
      "JACK 支持")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SYSTEM_INFO_KMS_SUPPORT,
      "KMS/EGL 支持")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SYSTEM_INFO_LIBRETRODB_SUPPORT,
      "LibretroDB 支持")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SYSTEM_INFO_LIBUSB_SUPPORT,
      "Libusb 支持")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SYSTEM_INFO_LIBXML2_SUPPORT,
      "libxml2 XML解析支持")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SYSTEM_INFO_NETPLAY_SUPPORT,
      "Netplay (點對點) 支持")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SYSTEM_INFO_NETWORK_COMMAND_IFACE_SUPPORT,
      "網路控制台支持")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SYSTEM_INFO_NETWORK_REMOTE_SUPPORT,
      "網路控制器支持")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SYSTEM_INFO_OPENAL_SUPPORT,
      "OpenAL 支持")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SYSTEM_INFO_OPENGLES_SUPPORT,
      "OpenGL ES 支持")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SYSTEM_INFO_OPENGL_SUPPORT,
      "OpenGL 支持")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SYSTEM_INFO_OPENSL_SUPPORT,
      "OpenSL 支持")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SYSTEM_INFO_OPENVG_SUPPORT,
      "OpenVG 支持")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SYSTEM_INFO_OSS_SUPPORT,
      "OSS 支持")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SYSTEM_INFO_OVERLAY_SUPPORT,
      "覆層支持")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SYSTEM_INFO_POWER_SOURCE,
      "電源")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SYSTEM_INFO_POWER_SOURCE_CHARGED,
      "已充滿電")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SYSTEM_INFO_POWER_SOURCE_CHARGING,
      "充電中")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SYSTEM_INFO_POWER_SOURCE_DISCHARGING,
      "放電中")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SYSTEM_INFO_POWER_SOURCE_NO_SOURCE,
      "沒有電源")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SYSTEM_INFO_PULSEAUDIO_SUPPORT,
      "PulseAudio 支持")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SYSTEM_INFO_PYTHON_SUPPORT,
      "Python (Shader中腳本支持) 支持")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SYSTEM_INFO_RBMP_SUPPORT,
      "BMP 支持 (RBMP)")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SYSTEM_INFO_RETRORATING_LEVEL,
      "RetroRating 等級")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SYSTEM_INFO_RJPEG_SUPPORT,
      "JPEG 支持 (RJPEG)")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SYSTEM_INFO_ROARAUDIO_SUPPORT,
      "RoarAudio 支持")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SYSTEM_INFO_RPNG_SUPPORT,
      "PNG 支持 (RPNG)")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SYSTEM_INFO_RSOUND_SUPPORT,
      "RSound 支持")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SYSTEM_INFO_RTGA_SUPPORT,
      "TGA 支持 (RTGA)")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SYSTEM_INFO_SDL2_SUPPORT,
      "SDL2 支持")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SYSTEM_INFO_SDL_IMAGE_SUPPORT,
      "SDL 圖像支持")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SYSTEM_INFO_SDL_SUPPORT,
      "SDL1.2 支持")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SYSTEM_INFO_SLANG_SUPPORT,
      "Slang 支持")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SYSTEM_INFO_THREADING_SUPPORT,
      "多線程支持")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SYSTEM_INFO_UDEV_SUPPORT,
      "Udev 支持")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SYSTEM_INFO_V4L2_SUPPORT,
      "Video4Linux2 支持")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SYSTEM_INFO_VIDEO_CONTEXT_DRIVER,
      "視訊上下文驅動")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SYSTEM_INFO_VULKAN_SUPPORT,
      "Vulkan 支持")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SYSTEM_INFO_WAYLAND_SUPPORT,
      "Wayland 支持")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SYSTEM_INFO_X11_SUPPORT,
      "X11 支持")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SYSTEM_INFO_XAUDIO2_SUPPORT,
      "XAudio2 支持")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SYSTEM_INFO_XVIDEO_SUPPORT,
      "XVideo 支持")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SYSTEM_INFO_ZLIB_SUPPORT,
      "Zlib 支持")
MSG_HASH(MENU_ENUM_LABEL_VALUE_TAKE_SCREENSHOT,
      "截取營幕")
MSG_HASH(MENU_ENUM_LABEL_VALUE_THREADED_DATA_RUNLOOP_ENABLE, /* TODO/FIXME - update */
      "啟用多線程數據執行循環")
MSG_HASH(MENU_ENUM_LABEL_VALUE_THUMBNAILS,
      "縮略圖")
MSG_HASH(MENU_ENUM_LABEL_VALUE_THUMBNAILS_DIRECTORY,
      "縮略圖目錄")
MSG_HASH(MENU_ENUM_LABEL_VALUE_THUMBNAILS_UPDATER_LIST,
      "縮略圖更新程序")
MSG_HASH(MENU_ENUM_LABEL_VALUE_THUMBNAIL_MODE_BOXARTS,
      "Boxarts")
MSG_HASH(MENU_ENUM_LABEL_VALUE_THUMBNAIL_MODE_SCREENSHOTS,
      "截屏")
MSG_HASH(MENU_ENUM_LABEL_VALUE_THUMBNAIL_MODE_TITLE_SCREENS,
      "標題畫面")
MSG_HASH(MENU_ENUM_LABEL_VALUE_TIMEDATE_ENABLE,
      "顯示時間日期")
MSG_HASH(MENU_ENUM_LABEL_VALUE_TITLE_COLOR,
      "選單標題顏色")
MSG_HASH(MENU_ENUM_LABEL_VALUE_TRUE,
      "真")
MSG_HASH(MENU_ENUM_LABEL_VALUE_UI_COMPANION_ENABLE,
      "UI Companion Enable")
MSG_HASH(MENU_ENUM_LABEL_VALUE_UI_COMPANION_START_ON_BOOT,
      "UI Companion Start On Boot")
MSG_HASH(MENU_ENUM_LABEL_VALUE_UI_MENUBAR_ENABLE,
      "Menubar")
MSG_HASH(MENU_ENUM_LABEL_VALUE_UNABLE_TO_READ_COMPRESSED_FILE,
      "無法讀取壓縮的文件。")
MSG_HASH(MENU_ENUM_LABEL_VALUE_UNDO_LOAD_STATE,
      "撤銷戴入狀態")
MSG_HASH(MENU_ENUM_LABEL_VALUE_UNDO_SAVE_STATE,
      "撤銷儲存狀態")
MSG_HASH(MENU_ENUM_LABEL_VALUE_UNKNOWN,
      "未知")
MSG_HASH(MENU_ENUM_LABEL_VALUE_UPDATER_SETTINGS,
      "更新程序")
MSG_HASH(MENU_ENUM_LABEL_VALUE_UPDATE_ASSETS,
      "更新資源")
MSG_HASH(MENU_ENUM_LABEL_VALUE_UPDATE_AUTOCONFIG_PROFILES,
      "更新自動設定檔案")
MSG_HASH(MENU_ENUM_LABEL_VALUE_UPDATE_CG_SHADERS,
      "更新CG Shader效果文件")
MSG_HASH(MENU_ENUM_LABEL_VALUE_UPDATE_CHEATS,
      "更新金手指")
MSG_HASH(MENU_ENUM_LABEL_VALUE_UPDATE_CORE_INFO_FILES,
      "更新核心訊息文件")
MSG_HASH(MENU_ENUM_LABEL_VALUE_UPDATE_DATABASES,
      "更新數據庫")
MSG_HASH(MENU_ENUM_LABEL_VALUE_UPDATE_GLSL_SHADERS,
      "更新GLSL Shader效果文件")
MSG_HASH(MENU_ENUM_LABEL_VALUE_UPDATE_LAKKA,
      "更新 Lakka")
MSG_HASH(MENU_ENUM_LABEL_VALUE_UPDATE_OVERLAYS,
      "更新覆層")
MSG_HASH(MENU_ENUM_LABEL_VALUE_UPDATE_SLANG_SHADERS,
      "更新Slang Shader效果文件")
MSG_HASH(MENU_ENUM_LABEL_VALUE_USER,
      "用戶")
MSG_HASH(MENU_ENUM_LABEL_VALUE_USER_INTERFACE_SETTINGS,
      "用戶界面")
MSG_HASH(MENU_ENUM_LABEL_VALUE_USER_LANGUAGE,
      "語言")
MSG_HASH(MENU_ENUM_LABEL_VALUE_USER_SETTINGS,
      "用戶")
MSG_HASH(MENU_ENUM_LABEL_VALUE_USE_BUILTIN_IMAGE_VIEWER,
      "使用內建的圖像瀏覽器")
MSG_HASH(MENU_ENUM_LABEL_VALUE_USE_BUILTIN_PLAYER,
      "使用內建媒體播放器")
MSG_HASH(MENU_ENUM_LABEL_VALUE_USE_THIS_DIRECTORY,
      "<使用當前目錄>")
MSG_HASH(MENU_ENUM_LABEL_VALUE_VIDEO_ALLOW_ROTATE,
      "允許旋轉")
MSG_HASH(MENU_ENUM_LABEL_VALUE_VIDEO_ASPECT_RATIO_AUTO,
      "自動選擇畫面比例")
MSG_HASH(MENU_ENUM_LABEL_VALUE_VIDEO_ASPECT_RATIO_INDEX,
      "畫面比例選項")
MSG_HASH(MENU_ENUM_LABEL_VALUE_VIDEO_BLACK_FRAME_INSERTION,
      "黑色幀補間")
MSG_HASH(MENU_ENUM_LABEL_VALUE_VIDEO_CROP_OVERSCAN,
      "Crop Overscan (Reload)")
MSG_HASH(MENU_ENUM_LABEL_VALUE_VIDEO_DISABLE_COMPOSITION,
      "禁用桌面元素")
MSG_HASH(MENU_ENUM_LABEL_VALUE_VIDEO_DRIVER,
      "視訊驅動")
MSG_HASH(MENU_ENUM_LABEL_VALUE_VIDEO_FILTER,
      "視訊濾鏡")
MSG_HASH(MENU_ENUM_LABEL_VALUE_VIDEO_FILTER_DIR,
      "視訊濾鏡目錄")
MSG_HASH(MENU_ENUM_LABEL_VALUE_VIDEO_FILTER_FLICKER,
      "閃爍過濾器")
MSG_HASH(MENU_ENUM_LABEL_VALUE_VIDEO_FONT_ENABLE,
      "顯示屏顯消息(OSD)")
MSG_HASH(MENU_ENUM_LABEL_VALUE_VIDEO_FONT_PATH,
      "屏顯消息(OSD)字體")
MSG_HASH(MENU_ENUM_LABEL_VALUE_VIDEO_FONT_SIZE,
      "屏顯消息(OSD)大小")
MSG_HASH(MENU_ENUM_LABEL_VALUE_VIDEO_FORCE_ASPECT,
      "強制畫面比例")
MSG_HASH(MENU_ENUM_LABEL_VALUE_VIDEO_FORCE_SRGB_DISABLE,
      "強制禁止sRGB幀緩衝")
MSG_HASH(MENU_ENUM_LABEL_VALUE_VIDEO_FRAME_DELAY,
      "幀延時")
MSG_HASH(MENU_ENUM_LABEL_VALUE_VIDEO_FULLSCREEN,
      "使用全屏模式")
MSG_HASH(MENU_ENUM_LABEL_VALUE_VIDEO_GAMMA,
      "視訊Gamma")
MSG_HASH(MENU_ENUM_LABEL_VALUE_VIDEO_GPU_RECORD,
      "啟用GPU錄影")
MSG_HASH(MENU_ENUM_LABEL_VALUE_VIDEO_GPU_SCREENSHOT,
      "啟用GPU截屏")
MSG_HASH(MENU_ENUM_LABEL_VALUE_VIDEO_HARD_SYNC,
      "強制GPU同步")
MSG_HASH(MENU_ENUM_LABEL_VALUE_VIDEO_HARD_SYNC_FRAMES,
      "強制GPU同步幀數")
MSG_HASH(MENU_ENUM_LABEL_VALUE_VIDEO_MAX_SWAPCHAIN_IMAGES,
      "最大交換鏈圖像數")
MSG_HASH(MENU_ENUM_LABEL_VALUE_VIDEO_MESSAGE_POS_X,
      "屏顯消息(OSD)X軸位置")
MSG_HASH(MENU_ENUM_LABEL_VALUE_VIDEO_MESSAGE_POS_Y,
      "屏顯消息(OSD)Y軸位置")
MSG_HASH(MENU_ENUM_LABEL_VALUE_VIDEO_MONITOR_INDEX,
      "顯示器索引")
MSG_HASH(MENU_ENUM_LABEL_VALUE_VIDEO_POST_FILTER_RECORD,
      "啟用錄影後期濾鏡")
MSG_HASH(MENU_ENUM_LABEL_VALUE_VIDEO_REFRESH_RATE,
      "刷新率")
MSG_HASH(MENU_ENUM_LABEL_VALUE_VIDEO_REFRESH_RATE_AUTO,
      "估算的顯示器幀率")
MSG_HASH(MENU_ENUM_LABEL_VALUE_VIDEO_REFRESH_RATE_POLLED,
      "Set Display-Reported Refresh Rate")
MSG_HASH(MENU_ENUM_LABEL_VALUE_VIDEO_ROTATION,
      "旋轉")
MSG_HASH(MENU_ENUM_LABEL_VALUE_VIDEO_SCALE,
      "窗口縮放量")
MSG_HASH(MENU_ENUM_LABEL_VALUE_VIDEO_SCALE_INTEGER,
      "整數化縮放量")
MSG_HASH(MENU_ENUM_LABEL_VALUE_VIDEO_SETTINGS,
      "視訊")
MSG_HASH(MENU_ENUM_LABEL_VALUE_VIDEO_SHADER_DIR,
      "視訊Shader目錄")
MSG_HASH(MENU_ENUM_LABEL_VALUE_VIDEO_SHADER_NUM_PASSES,
      "Shader渲染遍數")
MSG_HASH(MENU_ENUM_LABEL_VALUE_VIDEO_SHADER_PARAMETERS,
      "預覽Shader參數")
MSG_HASH(MENU_ENUM_LABEL_VALUE_VIDEO_SHADER_PRESET,
      "戴入Shader預設")
MSG_HASH(MENU_ENUM_LABEL_VALUE_VIDEO_SHADER_PRESET_SAVE_AS,
      "儲存Shader預設為")
MSG_HASH(MENU_ENUM_LABEL_VALUE_VIDEO_SHADER_PRESET_SAVE_CORE,
      "儲存核心預設")
MSG_HASH(MENU_ENUM_LABEL_VALUE_VIDEO_SHADER_PRESET_SAVE_GAME,
      "儲存遊戲預設")
MSG_HASH(MENU_ENUM_LABEL_VALUE_VIDEO_SHARED_CONTEXT,
      "啟用硬件共享上下文")
MSG_HASH(MENU_ENUM_LABEL_VALUE_VIDEO_SMOOTH,
      "硬件雙線性過濾")
MSG_HASH(MENU_ENUM_LABEL_VALUE_VIDEO_SOFT_FILTER,
      "啟用軟件過濾器")
MSG_HASH(MENU_ENUM_LABEL_VALUE_VIDEO_SWAP_INTERVAL,
      "垂直同步交換間隔")
MSG_HASH(MENU_ENUM_LABEL_VALUE_VIDEO_TAB,
      "視訊")
MSG_HASH(MENU_ENUM_LABEL_VALUE_VIDEO_THREADED,
      "多線程渲染")
MSG_HASH(MENU_ENUM_LABEL_VALUE_VIDEO_VFILTER,
      "降低閃爍")
MSG_HASH(MENU_ENUM_LABEL_VALUE_VIDEO_VIEWPORT_CUSTOM_HEIGHT,
      "自定義畫面高度")
MSG_HASH(MENU_ENUM_LABEL_VALUE_VIDEO_VIEWPORT_CUSTOM_WIDTH,
      "自定義畫面寬度")
MSG_HASH(MENU_ENUM_LABEL_VALUE_VIDEO_VIEWPORT_CUSTOM_X,
      "自定義畫面X")
MSG_HASH(MENU_ENUM_LABEL_VALUE_VIDEO_VIEWPORT_CUSTOM_Y,
      "自定義畫面Y")
MSG_HASH(MENU_ENUM_LABEL_VALUE_VIDEO_VI_WIDTH,
      "設定 VI 營幕寬度")
MSG_HASH(MENU_ENUM_LABEL_VALUE_VIDEO_VSYNC,
      "垂直同步")
MSG_HASH(MENU_ENUM_LABEL_VALUE_VIDEO_WINDOWED_FULLSCREEN,
      "無邊框窗口全屏模式")
MSG_HASH(MENU_ENUM_LABEL_VALUE_VIDEO_WINDOW_WIDTH,
      "窗口寬度")
MSG_HASH(MENU_ENUM_LABEL_VALUE_VIDEO_WINDOW_HEIGHT,
      "窗口高度")
MSG_HASH(MENU_ENUM_LABEL_VALUE_WIFI_DRIVER,
      "Wi-Fi驅動")
MSG_HASH(MENU_ENUM_LABEL_VALUE_WIFI_SETTINGS,
      "Wi-Fi")
MSG_HASH(MENU_ENUM_LABEL_VALUE_XMB_ALPHA_FACTOR,
      "選單透明度因子")
MSG_HASH(MENU_ENUM_LABEL_VALUE_XMB_FONT,
      "選單字體")
MSG_HASH(MENU_ENUM_LABEL_VALUE_XMB_ICON_THEME_CUSTOM,
      "自定義")
MSG_HASH(MENU_ENUM_LABEL_VALUE_XMB_ICON_THEME_FLATUI,
      "FlatUI")
MSG_HASH(MENU_ENUM_LABEL_VALUE_XMB_ICON_THEME_MONOCHROME,
      "Monochrome")
MSG_HASH(MENU_ENUM_LABEL_VALUE_XMB_ICON_THEME_MONOCHROME_INVERTED,
      "Monochrome Inverted")
MSG_HASH(MENU_ENUM_LABEL_VALUE_XMB_ICON_THEME_SYSTEMATIC,
      "Systematic")
MSG_HASH(MENU_ENUM_LABEL_VALUE_XMB_ICON_THEME_NEOACTIVE,
      "NeoActive")
MSG_HASH(MENU_ENUM_LABEL_VALUE_XMB_ICON_THEME_PIXEL,
      "Pixel")
MSG_HASH(MENU_ENUM_LABEL_VALUE_XMB_ICON_THEME_RETROACTIVE,
      "RetroActive")
MSG_HASH(MENU_ENUM_LABEL_VALUE_XMB_ICON_THEME_RETROSYSTEM,
      "Retrosystem")
MSG_HASH(MENU_ENUM_LABEL_VALUE_XMB_ICON_THEME_DOTART,
      "Dot-Art")
MSG_HASH(MENU_ENUM_LABEL_VALUE_XMB_MENU_COLOR_THEME,
      "選單顏色主題")
MSG_HASH(MENU_ENUM_LABEL_VALUE_XMB_MENU_COLOR_THEME_APPLE_GREEN,
      "蘋果綠")
MSG_HASH(MENU_ENUM_LABEL_VALUE_XMB_MENU_COLOR_THEME_DARK,
      "深色")
MSG_HASH(MENU_ENUM_LABEL_VALUE_XMB_MENU_COLOR_THEME_DARK_PURPLE,
      "深紫色")
MSG_HASH(MENU_ENUM_LABEL_VALUE_XMB_MENU_COLOR_THEME_ELECTRIC_BLUE,
      "鐵藍色")
MSG_HASH(MENU_ENUM_LABEL_VALUE_XMB_MENU_COLOR_THEME_GOLDEN,
      "金色")
MSG_HASH(MENU_ENUM_LABEL_VALUE_XMB_MENU_COLOR_THEME_LEGACY_RED,
      "傳統紅")
MSG_HASH(MENU_ENUM_LABEL_VALUE_XMB_MENU_COLOR_THEME_MIDNIGHT_BLUE,
      "藍黑色")
MSG_HASH(MENU_ENUM_LABEL_VALUE_XMB_MENU_COLOR_THEME_PLAIN,
      "樸素")
MSG_HASH(MENU_ENUM_LABEL_VALUE_XMB_MENU_COLOR_THEME_UNDERSEA,
      "海底")
MSG_HASH(MENU_ENUM_LABEL_VALUE_XMB_MENU_COLOR_THEME_VOLCANIC_RED,
      "火山紅")
MSG_HASH(MENU_ENUM_LABEL_VALUE_XMB_RIBBON_ENABLE,
      "選單Shader管線")
MSG_HASH(MENU_ENUM_LABEL_VALUE_XMB_SCALE_FACTOR,
      "選單縮放因子")
MSG_HASH(MENU_ENUM_LABEL_VALUE_XMB_SHADOWS_ENABLE,
      "啟用圖標陰影")
MSG_HASH(MENU_ENUM_LABEL_VALUE_CONTENT_SHOW_HISTORY,
      "顯示歷史頁")
MSG_HASH(MENU_ENUM_LABEL_VALUE_CONTENT_SHOW_ADD,
      "顯示導入內容頁")
MSG_HASH(MENU_ENUM_LABEL_VALUE_CONTENT_SHOW_IMAGES,
      "顯示圖像頁")
MSG_HASH(MENU_ENUM_LABEL_VALUE_CONTENT_SHOW_MUSIC,
      "顯示音樂頁")
MSG_HASH(MENU_ENUM_LABEL_VALUE_CONTENT_SHOW_SETTINGS,
      "顯示設定頁")
MSG_HASH(MENU_ENUM_LABEL_VALUE_CONTENT_SHOW_VIDEO,
      "顯示視訊頁")
MSG_HASH(MENU_ENUM_LABEL_VALUE_XMB_LAYOUT,
      "Menu Layout")
MSG_HASH(MENU_ENUM_LABEL_VALUE_XMB_THEME,
      "選單圖標主題")
MSG_HASH(MENU_ENUM_LABEL_VALUE_YES,
      "是")
MSG_HASH(MENU_ENUM_LABEL_VIDEO_SHADER_PRESET_TWO,
      "Shader預設")
MSG_HASH(MENU_ENUM_SUBLABEL_CHEEVOS_ENABLE,
      "打開或關閉成就。更多內容請訪問 http://retroachievements.org")
MSG_HASH(MENU_ENUM_SUBLABEL_CHEEVOS_TEST_UNOFFICIAL,
      "為測試目的而打開或關閉非官方成就和/或測試版特性。")
MSG_HASH(MENU_ENUM_SUBLABEL_CHEEVOS_HARDCORE_MODE_ENABLE,
      "為所有遊戲打開或關閉存檔、金手指、回退、快進、暫停和慢動作。")
MSG_HASH(MENU_ENUM_SUBLABEL_DRIVER_SETTINGS,
      "修改驅動設定。")
MSG_HASH(MENU_ENUM_SUBLABEL_RETRO_ACHIEVEMENTS_SETTINGS,
      "修改成就設定。")
MSG_HASH(MENU_ENUM_SUBLABEL_CORE_SETTINGS,
      "修改核心設定。")
MSG_HASH(MENU_ENUM_SUBLABEL_RECORDING_SETTINGS,
      "修改錄製的設定。")
MSG_HASH(MENU_ENUM_SUBLABEL_ONSCREEN_DISPLAY_SETTINGS,
      "修改顯示覆蓋、鍵盤覆蓋和營幕通知的設定。")
MSG_HASH(MENU_ENUM_SUBLABEL_FRAME_THROTTLE_SETTINGS,
      "修改回滾、快進和慢動作的設定。")
MSG_HASH(MENU_ENUM_SUBLABEL_SAVING_SETTINGS,
      "修改存檔設定。")
MSG_HASH(MENU_ENUM_SUBLABEL_LOGGING_SETTINGS,
      "修改日誌設定。")
MSG_HASH(MENU_ENUM_SUBLABEL_USER_INTERFACE_SETTINGS,
      "修改用戶界面設定。")
MSG_HASH(MENU_ENUM_SUBLABEL_USER_SETTINGS,
      "修改帳號、用戶名和語言。")
MSG_HASH(MENU_ENUM_SUBLABEL_PRIVACY_SETTINGS,
      "修改你的隱私設定。")
MSG_HASH(MENU_ENUM_SUBLABEL_DIRECTORY_SETTINGS,
      "修改此系統的默認目錄。")
MSG_HASH(MENU_ENUM_SUBLABEL_PLAYLIST_SETTINGS,
      "修改遊戲列表設定。")
MSG_HASH(MENU_ENUM_SUBLABEL_NETWORK_SETTINGS,
      "修改網路設定。")
MSG_HASH(MENU_ENUM_SUBLABEL_ADD_CONTENT_LIST,
      "下載且/或者掃瞄遊戲內容，並將其加入你的收藏中。")
MSG_HASH(MENU_ENUM_SUBLABEL_AUDIO_SETTINGS,
      "調整聲音輸出的選項。")
MSG_HASH(MENU_ENUM_SUBLABEL_BLUETOOTH_ENABLE,
      "啟用或者禁止藍牙。")
MSG_HASH(MENU_ENUM_SUBLABEL_CONFIG_SAVE_ON_EXIT,
      "程序將在退出時儲存修改到設定文件。")
MSG_HASH(MENU_ENUM_SUBLABEL_CONFIGURATION_SETTINGS,
      "修改設定文件的默認設定。")
MSG_HASH(MENU_ENUM_SUBLABEL_CONFIGURATIONS_LIST,
      "管理和創建設定文件。")
MSG_HASH(MENU_ENUM_SUBLABEL_CPU_CORES,
      "CPU擁有的核心總數。")
MSG_HASH(MENU_ENUM_SUBLABEL_FPS_SHOW,
      "在營幕上顯示當前每秒的幀率。")
MSG_HASH(MENU_ENUM_SUBLABEL_INPUT_HOTKEY_BINDS,
      "設定熱鍵選項。")
MSG_HASH(MENU_ENUM_SUBLABEL_INPUT_MENU_ENUM_TOGGLE_GAMEPAD_COMBO,
      "控制器用來切出選單的組合鍵。")
MSG_HASH(MENU_ENUM_SUBLABEL_INPUT_SETTINGS,
      "調整遊戲控制器、鍵盤和鼠標的設定。")
MSG_HASH(MENU_ENUM_SUBLABEL_INPUT_USER_BINDS,
      "設定該用戶的控制選項。")
MSG_HASH(MENU_ENUM_SUBLABEL_LOG_VERBOSITY,
      "啟用或禁止向控制台打印日誌。")
MSG_HASH(MENU_ENUM_SUBLABEL_NETPLAY,
      "加入或者開啟一個連線多人遊戲的會話。")
MSG_HASH(MENU_ENUM_SUBLABEL_NETPLAY_LAN_SCAN_SETTINGS,
      "在局域網內搜索並連接聯網遊戲的主機。")
MSG_HASH(MENU_ENUM_SUBLABEL_INFORMATION_LIST_LIST,
      "顯示核心、網路和系統的訊息。顯示數據庫和光標的管理器。")
MSG_HASH(MENU_ENUM_SUBLABEL_ONLINE_UPDATER,
      "下載並更新RetroArch的附加插件和組件。")
MSG_HASH(MENU_ENUM_SUBLABEL_SAMBA_ENABLE,
      "啟用或者禁止網路文件夾共享(SAMBA)。")
MSG_HASH(MENU_ENUM_SUBLABEL_SERVICES_SETTINGS,
      "管理操作系統層級的服務。")
MSG_HASH(MENU_ENUM_SUBLABEL_SHOW_HIDDEN_FILES,
      "在文件瀏覽器中顯示隱藏的文件或文件夾。")
MSG_HASH(MENU_ENUM_SUBLABEL_SSH_ENABLE,
      "啟用或者禁止遠程終端訪問(SSH)。")
MSG_HASH(MENU_ENUM_SUBLABEL_SUSPEND_SCREENSAVER_ENABLE,
      "阻止系統激活營幕保護程序。")
MSG_HASH(MENU_ENUM_SUBLABEL_USER_LANGUAGE,
      "設定用戶界面的語言。")
MSG_HASH(MENU_ENUM_SUBLABEL_VIDEO_BLACK_FRAME_INSERTION,
      "在幀與幀之間插入黑色的中間幀，通常用於消除在\n"
      "120Hz刷新率的顯示器上運行60Hz的遊戲內容帶來\n"
      "的鬼影。")
MSG_HASH(MENU_ENUM_SUBLABEL_VIDEO_FRAME_DELAY,
      "以增加畫面卡頓的風險換取低延時，在垂直同步後增加\n"
      "時延(毫秒)。")
MSG_HASH(MENU_ENUM_SUBLABEL_VIDEO_HARD_SYNC_FRAMES,
      "設定當開啟「強制GPU同步」時CPU可以預先GPU多少幀。")
MSG_HASH(MENU_ENUM_SUBLABEL_VIDEO_MAX_SWAPCHAIN_IMAGES,
      "強制顯示驅動程序使用特定的緩衝模式。")
MSG_HASH(MENU_ENUM_SUBLABEL_VIDEO_MONITOR_INDEX,
      "選擇將要使用哪一個顯示器。")
MSG_HASH(MENU_ENUM_SUBLABEL_VIDEO_REFRESH_RATE_AUTO,
      "估算的顯示器刷新率(Hz)。")
MSG_HASH(MENU_ENUM_SUBLABEL_VIDEO_REFRESH_RATE_POLLED,
      "The refresh rate as reported by the display driver.")
MSG_HASH(MENU_ENUM_SUBLABEL_VIDEO_SETTINGS,
      "調整視訊輸出的選項。")
MSG_HASH(MENU_ENUM_SUBLABEL_WIFI_SETTINGS,
      "掃瞄無線網路並且建立連接。")
MSG_HASH(MENU_ENUM_SUBLABEL_HELP_LIST,
      "學習更多關於其是如何工作的。")
MSG_HASH(MSG_APPENDED_DISK,
      "Appended disk")
MSG_HASH(MSG_APPLICATION_DIR,
      "應用程序目錄")
MSG_HASH(MSG_APPLYING_SHADER,
      "載入 shader")
MSG_HASH(MSG_AUDIO_MUTED,
      "靜音。")
MSG_HASH(MSG_AUDIO_UNMUTED,
      "取消靜音。")
MSG_HASH(MSG_AUTOCONFIG_FILE_ERROR_SAVING,
      "儲存 autoconf 文件錯誤。")
MSG_HASH(MSG_AUTOCONFIG_FILE_SAVED_SUCCESSFULLY,
      "自動設定文件儲存成功。")
MSG_HASH(MSG_AUTOSAVE_FAILED,
      "無法初始化自動儲存。")
MSG_HASH(MSG_AUTO_SAVE_STATE_TO,
      "自動儲存狀態至")
MSG_HASH(MSG_BLOCKING_SRAM_OVERWRITE,
      "阻止 SRAM 覆蓋")
MSG_HASH(MSG_BRINGING_UP_COMMAND_INTERFACE_ON_PORT,
      "啟用通訊埠上的指令介面")
MSG_HASH(MSG_BYTES,
      "字節")
MSG_HASH(MSG_CANNOT_INFER_NEW_CONFIG_PATH,
      "無法推斷新的設定路徑，使用當前時間。")
MSG_HASH(MSG_CHEEVOS_HARDCORE_MODE_ENABLE,
      "硬核模式開啟：及時存檔和回放被禁用.")
MSG_HASH(MSG_COMPARING_WITH_KNOWN_MAGIC_NUMBERS,
      "與已知的magic numbers比較...")
MSG_HASH(MSG_COMPILED_AGAINST_API,
      "Compiled against API")
MSG_HASH(MSG_CONFIG_DIRECTORY_NOT_SET,
      "未設定設定目錄，無法儲存新的設定。")
MSG_HASH(MSG_CONNECTED_TO,
      "連接至")
MSG_HASH(MSG_CONTENT_CRC32S_DIFFER,
      "內容的CRC32s不同。無法使用不同的遊戲。")
MSG_HASH(MSG_CONTENT_LOADING_SKIPPED_IMPLEMENTATION_WILL_DO_IT,
      "跳過內容戴入。實現將自行戴入。")
MSG_HASH(MSG_CORE_DOES_NOT_SUPPORT_SAVESTATES,
      "核心不支持儲存狀態。")
MSG_HASH(MSG_CORE_OPTIONS_FILE_CREATED_SUCCESSFULLY,
      "模擬器核心設定檔建立成功.")
MSG_HASH(MSG_COULD_NOT_FIND_ANY_NEXT_DRIVER,
      "無法找到磁碟")
MSG_HASH(MSG_COULD_NOT_FIND_COMPATIBLE_SYSTEM,
      "無法找到相容系統.")
MSG_HASH(MSG_COULD_NOT_FIND_VALID_DATA_TRACK,
      "無法找到有效的數據軌")
MSG_HASH(MSG_COULD_NOT_OPEN_DATA_TRACK,
      "無法打開數據軌")
MSG_HASH(MSG_COULD_NOT_READ_CONTENT_FILE,
      "無法讀取內容文件")
MSG_HASH(MSG_COULD_NOT_READ_MOVIE_HEADER,
      "無法讀取視訊頭部訊息.")
MSG_HASH(MSG_COULD_NOT_READ_STATE_FROM_MOVIE,
      "無法讀取視訊狀態.")
MSG_HASH(MSG_CRC32_CHECKSUM_MISMATCH,
      "CRC32 checksum mismatch between content file and saved content checksum in replay file header; replay highly likely to desync on playback.")
MSG_HASH(MSG_CUSTOM_TIMING_GIVEN,
      "Custom timing given")
MSG_HASH(MSG_DECOMPRESSION_ALREADY_IN_PROGRESS,
      "解壓縮已在進行中。")
MSG_HASH(MSG_DECOMPRESSION_FAILED,
      "解壓縮失敗。")
MSG_HASH(MSG_DETECTED_VIEWPORT_OF,
      "Detected viewport of")
MSG_HASH(MSG_DID_NOT_FIND_A_VALID_CONTENT_PATCH,
      "無法找到任何有效的內容位置.")
MSG_HASH(MSG_DISCONNECT_DEVICE_FROM_A_VALID_PORT,
      "從連接埠離開.")
MSG_HASH(MSG_DISK_CLOSED,
      "已關閉")
MSG_HASH(MSG_DISK_EJECTED,
      "已彈出")
MSG_HASH(MSG_DOWNLOADING,
      "正在下載")
MSG_HASH(MSG_DOWNLOAD_FAILED,
      "下載失敗")
MSG_HASH(MSG_ERROR,
      "錯誤")
MSG_HASH(MSG_ERROR_LIBRETRO_CORE_REQUIRES_CONTENT,
      "Libretro core requires content, but nothing was provided.")
MSG_HASH(MSG_ERROR_LIBRETRO_CORE_REQUIRES_SPECIAL_CONTENT,
      "Libretro core requires special content, but none were provided.")
MSG_HASH(MSG_ERROR_PARSING_ARGUMENTS,
      "Error parsing arguments.")
MSG_HASH(MSG_ERROR_SAVING_CORE_OPTIONS_FILE,
      "Error saving core options file.")
MSG_HASH(MSG_ERROR_SAVING_REMAP_FILE,
      "Error saving remap file.")
MSG_HASH(MSG_ERROR_SAVING_SHADER_PRESET,
      "Error saving shader preset.")
MSG_HASH(MSG_EXTERNAL_APPLICATION_DIR,
      "外部應用程序目錄")
MSG_HASH(MSG_EXTRACTING,
      "正在解壓")
MSG_HASH(MSG_EXTRACTING_FILE,
      "解壓文件")
MSG_HASH(MSG_FAILED_SAVING_CONFIG_TO,
      "無法儲存設定到")
MSG_HASH(MSG_FAILED_TO,
      "Failed to")
MSG_HASH(MSG_FAILED_TO_ACCEPT_INCOMING_SPECTATOR,
      "無法讓觀眾加入.")
MSG_HASH(MSG_FAILED_TO_ALLOCATE_MEMORY_FOR_PATCHED_CONTENT,
      "無法配置記憶體給已俢改的遊戲")
MSG_HASH(MSG_FAILED_TO_APPLY_SHADER,
      "無法載入 shader.")
MSG_HASH(MSG_FAILED_TO_BIND_SOCKET,
      "無法連接通訊埠.")
MSG_HASH(MSG_FAILED_TO_CREATE_THE_DIRECTORY,
      "創建目錄失敗。")
MSG_HASH(MSG_FAILED_TO_EXTRACT_CONTENT_FROM_COMPRESSED_FILE,
      "從壓縮文件中提取內容失敗")
MSG_HASH(MSG_FAILED_TO_GET_NICKNAME_FROM_CLIENT,
      "從客戶端獲取暱稱失敗.")
MSG_HASH(MSG_FAILED_TO_LOAD,
      "無法戴入")
MSG_HASH(MSG_FAILED_TO_LOAD_CONTENT,
      "載入內容失敗")
MSG_HASH(MSG_FAILED_TO_LOAD_MOVIE_FILE,
      "載入視訊文件失敗")
MSG_HASH(MSG_FAILED_TO_LOAD_OVERLAY,
      "無法戴入 overlay.")
MSG_HASH(MSG_FAILED_TO_LOAD_STATE,
      "無法戴入 state ")
MSG_HASH(MSG_FAILED_TO_OPEN_LIBRETRO_CORE,
      "打開libretro核心失敗")
MSG_HASH(MSG_FAILED_TO_PATCH,
      "補丁應用失敗")
MSG_HASH(MSG_FAILED_TO_RECEIVE_HEADER_FROM_CLIENT,
      "無法接收連線端的資訊")
MSG_HASH(MSG_FAILED_TO_RECEIVE_NICKNAME,
      "無法接收暱稱.")
MSG_HASH(MSG_FAILED_TO_RECEIVE_NICKNAME_FROM_HOST,
      "無法接收主控端的暱稱.")
MSG_HASH(MSG_FAILED_TO_RECEIVE_NICKNAME_SIZE_FROM_HOST,
      "無法接收主控端的暱稱大小.")
MSG_HASH(MSG_FAILED_TO_RECEIVE_SRAM_DATA_FROM_HOST,
      "無法接收主控端 SRAM 資料.")
MSG_HASH(MSG_FAILED_TO_REMOVE_DISK_FROM_TRAY,
      "移除光碟失敗.")
MSG_HASH(MSG_FAILED_TO_REMOVE_TEMPORARY_FILE,
      "移除臨時文件失敗")
MSG_HASH(MSG_FAILED_TO_SAVE_SRAM,
      "SRAM 存檔失敗")
MSG_HASH(MSG_FAILED_TO_SAVE_STATE_TO,
      "即時存檔儲存失敗")
MSG_HASH(MSG_FAILED_TO_SEND_NICKNAME,
      "發送暱稱失敗.")
MSG_HASH(MSG_FAILED_TO_SEND_NICKNAME_SIZE,
      "發送暱稱尺寸失敗.")
MSG_HASH(MSG_FAILED_TO_SEND_NICKNAME_TO_CLIENT,
      "發送暱稱至客戶端失敗.")
MSG_HASH(MSG_FAILED_TO_SEND_NICKNAME_TO_HOST,
      "發送暱稱至主控端失敗.")
MSG_HASH(MSG_FAILED_TO_SEND_SRAM_DATA_TO_CLIENT,
      "發送SRAM數據至客戶端失敗.")
MSG_HASH(MSG_FAILED_TO_START_AUDIO_DRIVER,
      "聲音驅動啟動失敗，將在無聲音模式下繼續啟動。")
MSG_HASH(MSG_FAILED_TO_START_MOVIE_RECORD,
      "啟動視訊錄製失敗.")
MSG_HASH(MSG_FAILED_TO_START_RECORDING,
      "建用錄製視訊失敗.")
MSG_HASH(MSG_FAILED_TO_TAKE_SCREENSHOT,
      "營幕快照失敗.")
MSG_HASH(MSG_FAILED_TO_UNDO_LOAD_STATE,
      "Failed to undo load state.")
MSG_HASH(MSG_FAILED_TO_UNDO_SAVE_STATE,
      "Failed to undo save state.")
MSG_HASH(MSG_FAILED_TO_UNMUTE_AUDIO,
      "Failed to unmute audio.")
MSG_HASH(MSG_FATAL_ERROR_RECEIVED_IN,
      "Fatal error received in")
MSG_HASH(MSG_FILE_NOT_FOUND,
      "未找到文件")
MSG_HASH(MSG_FOUND_AUTO_SAVESTATE_IN,
      "Found auto savestate in")
MSG_HASH(MSG_FOUND_DISK_LABEL,
      "Found disk label")
MSG_HASH(MSG_FOUND_FIRST_DATA_TRACK_ON_FILE,
      "Found first data track on file")
MSG_HASH(MSG_FOUND_LAST_STATE_SLOT,
      "Found last state slot")
MSG_HASH(MSG_FOUND_SHADER,
      "Found shader")
MSG_HASH(MSG_FRAMES,
      "幀")
MSG_HASH(MSG_GAME_SPECIFIC_CORE_OPTIONS_FOUND_AT,
      "Per-Game Options: game-specific core options found at")
MSG_HASH(MSG_GOT_INVALID_DISK_INDEX,
      "Got invalid disk index.")
MSG_HASH(MSG_GRAB_MOUSE_STATE,
      "抓取鼠標狀態")
MSG_HASH(MSG_GAME_FOCUS_ON,
      "Game focus on")
MSG_HASH(MSG_GAME_FOCUS_OFF,
      "Game focus off")
MSG_HASH(MSG_HW_RENDERED_MUST_USE_POSTSHADED_RECORDING,
      "Libretro core is hardware rendered. Must use post-shaded recording as well.")
MSG_HASH(MSG_INFLATED_CHECKSUM_DID_NOT_MATCH_CRC32,
      "Inflated checksum did not match CRC32.")
MSG_HASH(MSG_INPUT_CHEAT,
      "輸入金手指")
MSG_HASH(MSG_INPUT_CHEAT_FILENAME,
      "金手指檔案")
MSG_HASH(MSG_INPUT_PRESET_FILENAME,
      "目前檔案")
MSG_HASH(MSG_INPUT_RENAME_ENTRY,
      "Rename Title")
MSG_HASH(MSG_INTERFACE,
      "接口")
MSG_HASH(MSG_INTERNAL_STORAGE,
      "內部存儲")
MSG_HASH(MSG_REMOVABLE_STORAGE,
      "可移除的儲存空間")
MSG_HASH(MSG_INVALID_NICKNAME_SIZE,
      "不合法暱稱大小.")
MSG_HASH(MSG_IN_BYTES,
      "(字節)")
MSG_HASH(MSG_IN_GIGABYTES,
      "(吉字節)")
MSG_HASH(MSG_IN_MEGABYTES,
      "(兆字節)")
MSG_HASH(MSG_LIBRETRO_ABI_BREAK,
      "is compiled against a different version of libretro than this libretro implementation.")
MSG_HASH(MSG_LIBRETRO_FRONTEND,
      "為libretro而設計的前端")
MSG_HASH(MSG_LOADED_STATE_FROM_SLOT,
      "戴入狀態從槽 #%d.")
MSG_HASH(MSG_LOADED_STATE_FROM_SLOT_AUTO,
      "戴入狀態從槽 #-1 (auto).")
MSG_HASH(MSG_LOADING,
      "正在戴入")
MSG_HASH(MSG_FIRMWARE,
      "一個或多個固件文件丟失")
MSG_HASH(MSG_LOADING_CONTENT_FILE,
      "正在戴入內容文件")
MSG_HASH(MSG_LOADING_HISTORY_FILE,
      "正在讀取歷史文件")
MSG_HASH(MSG_LOADING_STATE,
      "正在讀取存檔")
MSG_HASH(MSG_MEMORY,
      "內存")
MSG_HASH(MSG_MOVIE_FILE_IS_NOT_A_VALID_BSV1_FILE,
      "視訊不是有效的BSV1文件。")
MSG_HASH(MSG_MOVIE_FORMAT_DIFFERENT_SERIALIZER_VERSION,
      "視訊格式看起來使用了不同的序列化版本。很有可能失敗。")
MSG_HASH(MSG_MOVIE_PLAYBACK_ENDED,
      "視訊回放結束.")
MSG_HASH(MSG_MOVIE_RECORD_STOPPED,
      "停止視訊錄製。")
MSG_HASH(MSG_NETPLAY_FAILED,
      "初始化連線遊戲失敗。")
MSG_HASH(MSG_NO_CONTENT_STARTING_DUMMY_CORE,
      "沒有內容，啟動虛擬核心。")
MSG_HASH(MSG_NO_SAVE_STATE_HAS_BEEN_OVERWRITTEN_YET,
      "未覆蓋任何存檔。")
MSG_HASH(MSG_NO_STATE_HAS_BEEN_LOADED_YET,
      "沒有戴入任何存檔。")
MSG_HASH(MSG_OVERRIDES_ERROR_SAVING,
      "儲存覆蓋錯誤。")
MSG_HASH(MSG_OVERRIDES_SAVED_SUCCESSFULLY,
      "覆蓋儲存成功。")
MSG_HASH(MSG_PAUSED,
      "暫停。")
MSG_HASH(MSG_PROGRAM,
      "RetroArch")
MSG_HASH(MSG_READING_FIRST_DATA_TRACK,
      "讀取第一條數據軌...")
MSG_HASH(MSG_RECEIVED,
      "接收完畢")
MSG_HASH(MSG_RECORDING_TERMINATED_DUE_TO_RESIZE,
      "錄製因改變大小而停止。")
MSG_HASH(MSG_RECORDING_TO,
      "錄製到")
MSG_HASH(MSG_REDIRECTING_CHEATFILE_TO,
      "重定向金手指文件至")
MSG_HASH(MSG_REDIRECTING_SAVEFILE_TO,
      "Redirecting save file to")
MSG_HASH(MSG_REDIRECTING_SAVESTATE_TO,
      "Redirecting savestate to")
MSG_HASH(MSG_REMAP_FILE_SAVED_SUCCESSFULLY,
      "Remap file saved successfully.")
MSG_HASH(MSG_REMOVED_DISK_FROM_TRAY,
      "Removed disk from tray.")
MSG_HASH(MSG_REMOVING_TEMPORARY_CONTENT_FILE,
      "移除臨時內容文件")
MSG_HASH(MSG_RESET,
      "重置")
MSG_HASH(MSG_RESTARTING_RECORDING_DUE_TO_DRIVER_REINIT,
      "重啟錄製由於驅動器重新初始化。")
MSG_HASH(MSG_RESTORED_OLD_SAVE_STATE,
      "重載舊的存檔。")
MSG_HASH(MSG_RESTORING_DEFAULT_SHADER_PRESET_TO,
      "Shaders: restoring default shader preset to")
MSG_HASH(MSG_REVERTING_SAVEFILE_DIRECTORY_TO,
      "Reverting savefile directory to")
MSG_HASH(MSG_REVERTING_SAVESTATE_DIRECTORY_TO,
      "Reverting savestate directory to")
MSG_HASH(MSG_REWINDING,
      "正在回溯。")
MSG_HASH(MSG_REWIND_INIT,
      "Initializing rewind buffer with size")
MSG_HASH(MSG_REWIND_INIT_FAILED,
      "初始化回放緩存失敗. 回放功能關閉.")
MSG_HASH(MSG_REWIND_INIT_FAILED_THREADED_AUDIO,
      "Implementation uses threaded audio. Cannot use rewind.")
MSG_HASH(MSG_REWIND_REACHED_END,
      "到達回放緩存末端.")
MSG_HASH(MSG_SAVED_NEW_CONFIG_TO,
      "已儲存新設定到")
MSG_HASH(MSG_SAVED_STATE_TO_SLOT,
      "儲存狀態至槽 #%d.")
MSG_HASH(MSG_SAVED_STATE_TO_SLOT_AUTO,
      "儲存狀態至槽 #-1 (auto).")
MSG_HASH(MSG_SAVED_SUCCESSFULLY_TO,
      "成功儲存至")
MSG_HASH(MSG_SAVING_RAM_TYPE,
      "儲存 RAM 類型")
MSG_HASH(MSG_SAVING_STATE,
      "存檔中")
MSG_HASH(MSG_SCANNING,
      "掃瞄中")
MSG_HASH(MSG_SCANNING_OF_DIRECTORY_FINISHED,
      "已完成對文件夾的掃瞄")
MSG_HASH(MSG_SENDING_COMMAND,
      "發送指令")
MSG_HASH(MSG_SEVERAL_PATCHES_ARE_EXPLICITLY_DEFINED,
      "Several patches are explicitly defined, ignoring all...")
MSG_HASH(MSG_SHADER,
      "Shader")
MSG_HASH(MSG_SHADER_PRESET_SAVED_SUCCESSFULLY,
      "Shader preset saved successfully.")
MSG_HASH(MSG_SKIPPING_SRAM_LOAD,
      "跳過 SRAM 戴入。")
MSG_HASH(MSG_SLOW_MOTION,
      "慢動作。")
MSG_HASH(MSG_FAST_FORWARD,
      "快進。")
MSG_HASH(MSG_SLOW_MOTION_REWIND,
      "慢動作回溯。")
MSG_HASH(MSG_SRAM_WILL_NOT_BE_SAVED,
      "SRAM 將不會被儲存.")
MSG_HASH(MSG_STARTING_MOVIE_PLAYBACK,
      "視訊回放.")
MSG_HASH(MSG_STARTING_MOVIE_RECORD_TO,
      "Starting movie record to")
MSG_HASH(MSG_STATE_SIZE,
      "即時存檔大小")
MSG_HASH(MSG_STATE_SLOT,
      "狀態存檔槽")
MSG_HASH(MSG_TAKING_SCREENSHOT,
      "截屏。")
MSG_HASH(MSG_TO,
      "到")
MSG_HASH(MSG_UNDID_LOAD_STATE,
      "已撤銷戴入狀態。")
MSG_HASH(MSG_UNDOING_SAVE_STATE,
      "撤銷即時存檔")
MSG_HASH(MSG_UNKNOWN,
      "未知")
MSG_HASH(MSG_UNPAUSED,
      "取消暫停。")
MSG_HASH(MSG_UNRECOGNIZED_COMMAND,
      "無法識別的指令")
MSG_HASH(MSG_USING_CORE_NAME_FOR_NEW_CONFIG,
      "Using core name for new config.")
MSG_HASH(MSG_USING_LIBRETRO_DUMMY_CORE_RECORDING_SKIPPED,
      "使用libretro虛擬核心。跳過錄製。")
MSG_HASH(MSG_VALUE_CONNECT_DEVICE_FROM_A_VALID_PORT,
      "Connect device from a valid port.")
MSG_HASH(MSG_VALUE_DISCONNECTING_DEVICE_FROM_PORT,
      "從端口斷開設備")
MSG_HASH(MSG_VALUE_REBOOTING,
      "正在重啟……")
MSG_HASH(MSG_VALUE_SHUTTING_DOWN,
      "正在關機……")
MSG_HASH(MSG_VERSION_OF_LIBRETRO_API,
      "libretro API版本")
MSG_HASH(MSG_VIEWPORT_SIZE_CALCULATION_FAILED,
      "Viewport size calculation failed! Will continue using raw data. This will probably not work right ...")
MSG_HASH(MSG_VIRTUAL_DISK_TRAY,
      "virtual disk tray.")
MSG_HASH(MENU_ENUM_SUBLABEL_AUDIO_LATENCY,
      "Desired audio latency in milliseconds. Might not be honored if the audio driver can't provide given latency.")
MSG_HASH(MENU_ENUM_SUBLABEL_AUDIO_MUTE,
      "禁音/取消禁音。")
MSG_HASH(
      MENU_ENUM_SUBLABEL_AUDIO_RATE_CONTROL_DELTA,
      "Helps smooth out imperfections in timing when synchronizing audio and video at the same time. Be aware that if disabled, proper synchronization is nearly impossible to obtain."
      )
MSG_HASH(
      MENU_ENUM_SUBLABEL_CAMERA_ALLOW,
      "允許或禁止核心使用攝像頭。"
      )
MSG_HASH(
      MENU_ENUM_SUBLABEL_LOCATION_ALLOW,
      "Allow or disallow location services access by cores."
      )
MSG_HASH(
      MENU_ENUM_SUBLABEL_INPUT_MAX_USERS,
      "RetroArch 最大遊戲支援人數"
      )
MSG_HASH(
      MENU_ENUM_SUBLABEL_INPUT_POLL_TYPE_BEHAVIOR,
      "Influence how input polling is done inside RetroArch. Setting it to 'Early' or 'Late' can result in less latency, depending on your configuration."
      )
MSG_HASH(
      MENU_ENUM_SUBLABEL_INPUT_ALL_USERS_CONTROL_MENU,
      "允許任何使用者去控制選單，如果取消，將只會有1個人可以控制選單."
      )
MSG_HASH(
      MENU_ENUM_SUBLABEL_AUDIO_VOLUME,
      "音量大小 (in dB). 0 dB 是標準大小."
      )
MSG_HASH(
   MENU_ENUM_SUBLABEL_AUDIO_SYNC,
   "同步聲音。推薦。"
   )
MSG_HASH(
   MENU_ENUM_SUBLABEL_INPUT_AXIS_THRESHOLD,
   "How far an axis must be tilted to result in a button press."
   )
MSG_HASH(
   MENU_ENUM_SUBLABEL_INPUT_BIND_TIMEOUT,
   "Amount of seconds to wait until proceeding to the next bind."
   )
MSG_HASH(
   MENU_ENUM_SUBLABEL_INPUT_TURBO_PERIOD,
   "Describes the period of which turbo-enabled buttons toggle. Numbers are described in frames."
   )
MSG_HASH(
   MENU_ENUM_SUBLABEL_INPUT_DUTY_CYCLE,
   "Describes how long the period of a turbo-enabled button should be. Numbers are described in frames."
   )
MSG_HASH(
   MENU_ENUM_SUBLABEL_VIDEO_VSYNC,
   "同步顯卡的視訊輸出到營幕刷新率。推薦。"
   )
MSG_HASH(
   MENU_ENUM_SUBLABEL_VIDEO_ALLOW_ROTATE,
   "Allow cores to set rotation. When disabled, rotation requests are ignored. Useful for setups where one manually rotates the screen."
   )
MSG_HASH(
   MENU_ENUM_SUBLABEL_DUMMY_ON_CORE_SHUTDOWN,
   "Some cores might have a shutdown feature. If enabled, it will prevent the core from shutting RetroArch down. Instead, it loads a dummy core."
   )
MSG_HASH(
   MENU_ENUM_SUBLABEL_CHECK_FOR_MISSING_FIRMWARE,
   "載入遊戲前檢查必要的韌體/BIOS是否存在."
   )
MSG_HASH(
   MENU_ENUM_SUBLABEL_VIDEO_REFRESH_RATE,
   "Vertical refresh rate of your screen. Used to calculate a suitable audio input rate. NOTE: This will be ignored if 'Threaded Video' is enabled."
   )
MSG_HASH(
   MENU_ENUM_SUBLABEL_AUDIO_ENABLE,
   "啟用聲音輸出。"
   )
MSG_HASH(
   MENU_ENUM_SUBLABEL_AUDIO_MAX_TIMING_SKEW,
   "The maximum change in audio input rate. You may want to increase this to enable very large changes in timing, for example running PAL cores on NTSC displays, at the cost of inaccurate audio pitch."
   )
MSG_HASH(
   MSG_FAILED,
   "已失敗"
   )
MSG_HASH(
   MSG_SUCCEEDED,
   "已成功"
   )
MSG_HASH(
   MSG_DEVICE_NOT_CONFIGURED,
   "未設定"
   )
MSG_HASH(
   MSG_DEVICE_NOT_CONFIGURED_FALLBACK,
   "未設定，將使用內定值"
   )
MSG_HASH(
   MENU_ENUM_LABEL_VALUE_DATABASE_CURSOR_LIST,
   "數據庫 Cursor List"
   )
MSG_HASH(
   MENU_ENUM_LABEL_VALUE_DATABASE_CURSOR_LIST_ENTRY_DEVELOPER,
   "數據庫 - 過濾器 : 開發者"
   )
MSG_HASH(
   MENU_ENUM_LABEL_VALUE_DATABASE_CURSOR_LIST_ENTRY_PUBLISHER,
   "數據庫 - 過濾器 : 發佈者"
   )
MSG_HASH(
   MENU_ENUM_LABEL_VALUE_DISABLED,
   "禁用"
   )
MSG_HASH(
   MENU_ENUM_LABEL_VALUE_ENABLED,
   "啟用"
   )
MSG_HASH(
   MENU_ENUM_LABEL_VALUE_CONTENT_HISTORY_PATH,
   "內容歷史路徑"
   )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_DATABASE_CURSOR_LIST_ENTRY_ORIGIN,
      "數據庫 - 過濾器 : Origin")
MSG_HASH(MENU_ENUM_LABEL_VALUE_DATABASE_CURSOR_LIST_ENTRY_FRANCHISE,
      "數據庫 - 過濾器 : Franchise")
MSG_HASH(MENU_ENUM_LABEL_VALUE_DATABASE_CURSOR_LIST_ENTRY_ESRB_RATING,
      "數據庫 - 過濾器 : ESRB Rating")
MSG_HASH(MENU_ENUM_LABEL_VALUE_DATABASE_CURSOR_LIST_ENTRY_ELSPA_RATING,
      "數據庫 - 過濾器 : ELSPA Rating")
MSG_HASH(MENU_ENUM_LABEL_VALUE_DATABASE_CURSOR_LIST_ENTRY_PEGI_RATING,
      "數據庫 - 過濾器 : PEGI Rating")
MSG_HASH(MENU_ENUM_LABEL_VALUE_DATABASE_CURSOR_LIST_ENTRY_CERO_RATING,
      "數據庫 - 過濾器 : CERO Rating")
MSG_HASH(MENU_ENUM_LABEL_VALUE_DATABASE_CURSOR_LIST_ENTRY_BBFC_RATING,
      "數據庫 - 過濾器 : BBFC Rating")
MSG_HASH(MENU_ENUM_LABEL_VALUE_DATABASE_CURSOR_LIST_ENTRY_MAX_USERS,
      "數據庫 - 過濾器 : 最大用戶數")
MSG_HASH(MENU_ENUM_LABEL_VALUE_DATABASE_CURSOR_LIST_ENTRY_RELEASEDATE_BY_MONTH,
      "數據庫 - 過濾器 : 發行月份")
MSG_HASH(MENU_ENUM_LABEL_VALUE_DATABASE_CURSOR_LIST_ENTRY_RELEASEDATE_BY_YEAR,
      "數據庫 - 過濾器 : 發行年代")
MSG_HASH(MENU_ENUM_LABEL_VALUE_DATABASE_CURSOR_LIST_ENTRY_EDGE_MAGAZINE_ISSUE,
      "數據庫 - 過濾器 : Edge Magazine Issue")
MSG_HASH(MENU_ENUM_LABEL_VALUE_DATABASE_CURSOR_LIST_ENTRY_EDGE_MAGAZINE_RATING,
      "數據庫 - 過濾器 : Edge Magazine Rating")
MSG_HASH(MENU_ENUM_LABEL_VALUE_DATABASE_CURSOR_LIST_ENTRY_DATABASE_INFO,
      "數據庫訊息")
MSG_HASH(MSG_WIFI_SCAN_COMPLETE,
      "Wi-Fi 掃瞄完成。")
MSG_HASH(MSG_SCANNING_WIRELESS_NETWORKS,
      "掃瞄無線網路...")
MSG_HASH(MSG_NETPLAY_LAN_SCAN_COMPLETE,
      "連線遊戲主機掃瞄完成。")
MSG_HASH(MSG_NETPLAY_LAN_SCANNING,
      "掃瞄連線遊戲主機...")
MSG_HASH(MENU_ENUM_SUBLABEL_PAUSE_NONACTIVE,
      "當窗口失去焦點時暫停遊戲。")
MSG_HASH(MENU_ENUM_SUBLABEL_VIDEO_DISABLE_COMPOSITION,
      "Enable or disable composition.")
MSG_HASH(MENU_ENUM_SUBLABEL_HISTORY_LIST_ENABLE,
      "為遊戲、圖片、音樂和視訊啟用/禁用歷史記錄。")
MSG_HASH(MENU_ENUM_SUBLABEL_CONTENT_HISTORY_SIZE,
      "遊戲、圖片、音樂和視訊歷史記錄的數量限制。")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_UNIFIED_MENU_CONTROLS,
      "統一選單控制")
MSG_HASH(MENU_ENUM_SUBLABEL_INPUT_UNIFIED_MENU_CONTROLS,
      "Use the same controls for both the menu and the game. Applies to the keyboard.")
MSG_HASH(MENU_ENUM_SUBLABEL_VIDEO_FONT_ENABLE,
      "顯示營幕消息。")
MSG_HASH(MENU_ENUM_LABEL_VALUE_NETWORK_USER_REMOTE_ENABLE,
      "用戶 %d 遠程允許")
MSG_HASH(MENU_ENUM_LABEL_VALUE_BATTERY_LEVEL_ENABLE,
      "顯示電池電量")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SELECT_FILE,
      "選擇文件")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SELECT_FROM_COLLECTION,
      "從收藏中選擇")
MSG_HASH(MENU_ENUM_LABEL_VALUE_FILTER,
      "過濾器")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SCALE,
      "刻度")
MSG_HASH(MENU_ENUM_LABEL_VALUE_NETPLAY_START_WHEN_LOADED,
      "連線遊戲將在內容戴入後開始。")
MSG_HASH(MENU_ENUM_LABEL_VALUE_NETPLAY_LOAD_CONTENT_MANUALLY,
      "無法找到合適的核心或內容文件，手動戴入。")
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_BROWSE_URL_LIST,
      "瀏覽URL"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_BROWSE_URL,
      "URL路徑"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_BROWSE_START,
      "開始"
      )
MSG_HASH(MENU_ENUM_LABEL_VALUE_SHADER_PIPELINE_BOKEH,
      "Bokeh")
MSG_HASH(MENU_ENUM_LABEL_VALUE_NETPLAY_REFRESH_ROOMS,
      "更新 Room 列表")
MSG_HASH(MENU_ENUM_LABEL_VALUE_NETPLAY_ROOM_NICKNAME,
      "暱稱: %s")
MSG_HASH(MENU_ENUM_LABEL_VALUE_NETPLAY_ROOM_NICKNAME_LAN,
      "暱稱 (lan): %s")
MSG_HASH(MENU_ENUM_LABEL_VALUE_NETPLAY_COMPAT_CONTENT_FOUND,
      "找到相容遊戲")
MSG_HASH(MENU_ENUM_SUBLABEL_VIDEO_CROP_OVERSCAN,
      "Cuts off a few pixels around the edges of the image customarily left blank by developers which sometimes also contain garbage pixels.")
MSG_HASH(MENU_ENUM_SUBLABEL_VIDEO_SMOOTH,
      "Adds a slight blur to the image to take the edge off of the hard pixel edges. This option has very little impact on performance.")
MSG_HASH(MENU_ENUM_SUBLABEL_VIDEO_FILTER,
      "Apply a CPU-powered video filter. NOTE: Might come at a high performance cost. Some video filters might only work for cores that use 32bit or 16bit color.")
MSG_HASH(MENU_ENUM_SUBLABEL_CHEEVOS_USERNAME,
      "輸入Retro Achievements 的帳號.")
MSG_HASH(MENU_ENUM_SUBLABEL_CHEEVOS_PASSWORD,
      "輸入Retro Achievements 的密碼.")
MSG_HASH(MENU_ENUM_SUBLABEL_NETPLAY_NICKNAME,
      "Input your user name here. This will be used for netplay sessions, among other things.")
MSG_HASH(MENU_ENUM_SUBLABEL_VIDEO_POST_FILTER_RECORD,
      "Capture the image after filters (but not shaders) are applied. Your video will look as fancy as what you see on your screen.")
MSG_HASH(MENU_ENUM_SUBLABEL_CORE_LIST,
      "Select which core to use.")
MSG_HASH(MENU_ENUM_SUBLABEL_LOAD_CONTENT_LIST,
      "Select which content to start.")
MSG_HASH(MENU_ENUM_SUBLABEL_NETWORK_INFORMATION,
      "Show network interface(s) and associated IP addresses.")
MSG_HASH(MENU_ENUM_SUBLABEL_SYSTEM_INFORMATION,
      "Show information specific to the device.")
MSG_HASH(MENU_ENUM_SUBLABEL_QUIT_RETROARCH,
      "離開程式.")
MSG_HASH(MENU_ENUM_SUBLABEL_VIDEO_WINDOW_WIDTH,
      "Set the custom width size for the display window. Leaving it at 0 will attempt to scale the window as large as possible.")
MSG_HASH(MENU_ENUM_SUBLABEL_VIDEO_WINDOW_HEIGHT,
      "Set the custom height size for the display window. Leaving it at 0 will attempt to scale the window as large as possible.")
MSG_HASH(MENU_ENUM_SUBLABEL_VIDEO_FULLSCREEN_X,
      "Set the custom width size for the non-windowed fullscreen mode. Leaving it at 0 will use the desktop resolution.")
MSG_HASH(MENU_ENUM_SUBLABEL_VIDEO_FULLSCREEN_Y,
      "Set the custom height size for the non-windowed fullscreen mode. Leaving it at 0 will use the desktop resolution")
MSG_HASH(MENU_ENUM_SUBLABEL_VIDEO_MESSAGE_POS_X,
      "Specify custom X axis position for onscreen text.")
MSG_HASH(MENU_ENUM_SUBLABEL_VIDEO_MESSAGE_POS_Y,
      "Specify custom Y axis position for onscreen text.")
MSG_HASH(MENU_ENUM_SUBLABEL_VIDEO_FONT_SIZE,
      "Specify the font size in points.")
MSG_HASH(MENU_ENUM_SUBLABEL_INPUT_OVERLAY_HIDE_IN_MENU,
      "Hide the overlay while inside the menu, and show it again when exiting the menu.")
MSG_HASH(
      MENU_ENUM_SUBLABEL_CONTENT_COLLECTION_LIST,
      "Scanned content will appear here."
      )
MSG_HASH(
      MENU_ENUM_SUBLABEL_VIDEO_SCALE_INTEGER,
      "Only scales video in integer steps. The base size depends on system-reported geometry and aspect ratio. If 'Force Aspect' is not set, X/Y will be integer scaled independently."
      )
MSG_HASH(
      MENU_ENUM_SUBLABEL_VIDEO_GPU_SCREENSHOT,
      "Screenshots output of GPU shaded material if available."
      )
MSG_HASH(
      MENU_ENUM_SUBLABEL_VIDEO_ROTATION,
      "Forces a certain rotation of the screen. The rotation is added to rotations which the core sets."
      )
MSG_HASH(
      MENU_ENUM_SUBLABEL_VIDEO_FORCE_SRGB_DISABLE,
      "Forcibly disable sRGB FBO support. Some Intel OpenGL drivers on Windows have video problems with sRGB FBO support if this is enabled. Enabling this can work around it."
      )
MSG_HASH(
      MENU_ENUM_SUBLABEL_VIDEO_FULLSCREEN,
      "Start in fullscreen. Can be changed at runtime."
      )
MSG_HASH(
      MENU_ENUM_SUBLABEL_VIDEO_WINDOWED_FULLSCREEN,
      "If fullscreen, prefer using a windowed fullscreen mode."
      )
MSG_HASH(
      MENU_ENUM_SUBLABEL_VIDEO_GPU_RECORD,
      "Records output of GPU shaded material if available."
      )
MSG_HASH(
      MENU_ENUM_SUBLABEL_SAVESTATE_AUTO_INDEX,
      "When making a savestate, save state index is automatically increased before it is saved. When loading content, the index will be set to the highest existing index."
      )
MSG_HASH(
      MENU_ENUM_SUBLABEL_BLOCK_SRAM_OVERWRITE,
      "Block Save RAM from being overwritten when loading save states. Might potentially lead to buggy games."
      )
MSG_HASH(
      MENU_ENUM_SUBLABEL_FASTFORWARD_RATIO,
      "The maximum rate at which content will be run when using fast forward (e.g., 5.0x for 60 fps content = 300 fps cap). If set to 0.0x, fastforward ratio is unlimited (no FPS cap)."
      )
MSG_HASH(
      MENU_ENUM_SUBLABEL_SLOWMOTION_RATIO,
      "When in slow motion, content will slow down by the factor specified/set."
      )
MSG_HASH(
      MENU_ENUM_SUBLABEL_REWIND_ENABLE,
      "Enable rewinding. This will take a performance hit when playing."
      )
MSG_HASH(
      MENU_ENUM_SUBLABEL_REWIND_GRANULARITY,
      "When rewinding a defined number of frames, you can rewind several frames at a time, increasing the rewind speed."
      )
MSG_HASH(
      MENU_ENUM_SUBLABEL_LIBRETRO_LOG_LEVEL,
      "Sets log level for cores. If a log level issued by a core is below this value, it is ignored."
      )
MSG_HASH(
      MENU_ENUM_SUBLABEL_PERFCNT_ENABLE,
      "Enable performance counters for RetroArch (and cores)."
      )
MSG_HASH(
      MENU_ENUM_SUBLABEL_SAVESTATE_AUTO_SAVE,
      "Automatically makes a savestate at the end of RetroArch's runtime. RetroArch will automatically load this savestate if 'Auto Load State' is enabled."
      )
MSG_HASH(
      MENU_ENUM_SUBLABEL_SAVESTATE_AUTO_LOAD,
      "Automatically load the auto save state on startup."
      )
MSG_HASH(
      MENU_ENUM_SUBLABEL_SAVESTATE_THUMBNAIL_ENABLE,
      "Show thumbnails of save states inside the menu."
      )
MSG_HASH(
      MENU_ENUM_SUBLABEL_AUTOSAVE_INTERVAL,
      "Autosaves the non-volatile Save RAM at a regular interval. This is disabled by default unless set otherwise. The interval is measured in seconds. A value of 0 disables autosave."
      )
MSG_HASH(
      MENU_ENUM_SUBLABEL_INPUT_REMAP_BINDS_ENABLE,
      "If enabled, overrides the input binds with the remapped binds set for the current core."
      )
MSG_HASH(
      MENU_ENUM_SUBLABEL_INPUT_AUTODETECT_ENABLE,
      "Enable input auto-detection. Will attempt to autoconfigure joypads, Plug-and-Play style."
      )
MSG_HASH(
      MENU_ENUM_SUBLABEL_MENU_INPUT_SWAP_OK_CANCEL,
      "Swap buttons for OK/Cancel. Disabled is the Japanese button orientation, enabled is the western orientation."
      )
MSG_HASH(
      MENU_ENUM_SUBLABEL_PAUSE_LIBRETRO,
      "If disabled, the content will keep running in the background when RetroArch's menu is toggled."
      )
MSG_HASH(
      MENU_ENUM_SUBLABEL_VIDEO_DRIVER,
      "Video driver to use."
      )
MSG_HASH(
      MENU_ENUM_SUBLABEL_AUDIO_DRIVER,
      "Audio driver to use."
      )
MSG_HASH(
      MENU_ENUM_SUBLABEL_INPUT_DRIVER,
      "Input driver to use. Depending on the video driver, it might force a different input driver."
      )
MSG_HASH(
      MENU_ENUM_SUBLABEL_JOYPAD_DRIVER,
      "Joypad driver to use."
      )
MSG_HASH(
      MENU_ENUM_SUBLABEL_AUDIO_RESAMPLER_DRIVER,
      "Audio resampler driver to use."
      )
MSG_HASH(
      MENU_ENUM_SUBLABEL_CAMERA_DRIVER,
      "Camera driver to use."
      )
MSG_HASH(
      MENU_ENUM_SUBLABEL_LOCATION_DRIVER,
      "Location driver to use."
      )
MSG_HASH(
      MENU_ENUM_SUBLABEL_MENU_DRIVER,
      "Menu driver to use."
      )
MSG_HASH(
      MENU_ENUM_SUBLABEL_RECORD_DRIVER,
      "Record driver to use."
      )
MSG_HASH(
      MENU_ENUM_SUBLABEL_WIFI_DRIVER,
      "WiFi driver to use."
      )
MSG_HASH(
      MENU_ENUM_SUBLABEL_NAVIGATION_BROWSER_FILTER_SUPPORTED_EXTENSIONS_ENABLE,
      "Filter files being shown in filebrowser by supported extensions."
      )
MSG_HASH(
      MENU_ENUM_SUBLABEL_MENU_WALLPAPER,
      "Select an image to set as menu wallpaper."
      )
MSG_HASH(
      MENU_ENUM_SUBLABEL_DYNAMIC_WALLPAPER,
      "Dynamically load a new wallpaper depending on context."
      )
MSG_HASH(
      MENU_ENUM_SUBLABEL_AUDIO_DEVICE,
      "Override the default audio device the audio driver uses. This is driver dependent."
      )
MSG_HASH(
      MENU_ENUM_SUBLABEL_AUDIO_DSP_PLUGIN,
      "Audio DSP plugin that processes audio before it's sent to the driver."
      )
MSG_HASH(
      MENU_ENUM_SUBLABEL_AUDIO_OUTPUT_RATE,
      "Audio output sample rate."
      )
MSG_HASH(
      MENU_ENUM_SUBLABEL_OVERLAY_OPACITY,
      "Opacity of all UI elements of the overlay."
      )
MSG_HASH(
      MENU_ENUM_SUBLABEL_OVERLAY_SCALE,
      "Scale of all UI elements of the overlay."
      )
MSG_HASH(
      MENU_ENUM_SUBLABEL_INPUT_OVERLAY_ENABLE,
      "Enable the overlay."
      )
MSG_HASH(
      MENU_ENUM_SUBLABEL_OVERLAY_PRESET,
      "Select an overlay from the file browser."
      )
MSG_HASH(
      MENU_ENUM_SUBLABEL_NETPLAY_IP_ADDRESS,
      "The address of the host to connect to."
      )
MSG_HASH(
      MENU_ENUM_SUBLABEL_NETPLAY_TCP_UDP_PORT,
      "The port of the host IP address. Can be either a TCP or UDP port."
      )
MSG_HASH(
      MENU_ENUM_SUBLABEL_NETPLAY_PASSWORD,
      "The password for connecting to the netplay host. Used only in host mode."
      )
MSG_HASH(
      MENU_ENUM_SUBLABEL_NETPLAY_PUBLIC_ANNOUNCE,
      "Whether to announce netplay games publicly. If unset, clients must manually connect rather than using the public lobby."
      )
MSG_HASH(
      MENU_ENUM_SUBLABEL_NETPLAY_SPECTATE_PASSWORD,
      "The password for connecting to the netplay host with only spectator privileges. Used only in host mode."
      )
MSG_HASH(
      MENU_ENUM_SUBLABEL_NETPLAY_START_AS_SPECTATOR,
      "Whether to start netplay in spectator mode."
      )
MSG_HASH(
      MENU_ENUM_SUBLABEL_NETPLAY_ALLOW_SLAVES,
      "Whether to allow connections in slave mode. Slave-mode clients require very little processing power on either side, but will suffer significantly from network latency."
      )
MSG_HASH(
      MENU_ENUM_SUBLABEL_NETPLAY_REQUIRE_SLAVES,
      "Whether to disallow connections not in slave mode. Not recommended except for very fast networks with very weak machines."
      )
MSG_HASH(
      MENU_ENUM_SUBLABEL_NETPLAY_STATELESS_MODE,
      "Whether to run netplay in a mode not requiring save states. If set to true, a very fast network is required, but no rewinding is performed, so there will be no netplay jitter."
      )
MSG_HASH(
      MENU_ENUM_SUBLABEL_NETPLAY_CHECK_FRAMES,
      "The frequency in frames with which netplay will verify that the host and client are in sync."
      )
MSG_HASH(
      MENU_ENUM_SUBLABEL_NETPLAY_NAT_TRAVERSAL,
      "When hosting, attempt to listen for connections from the public Internet, using UPnP or similar technologies to escape LANs."
      )
MSG_HASH(
      MENU_ENUM_SUBLABEL_STDIN_CMD_ENABLE,
      "Enable stdin command interface."
      )
MSG_HASH(
      MENU_ENUM_SUBLABEL_MOUSE_ENABLE,
      "Enable mouse controls inside the menu."
      )
MSG_HASH(
      MENU_ENUM_SUBLABEL_POINTER_ENABLE,
      "Enable touch controls inside the menu."
      )
MSG_HASH(
      MENU_ENUM_SUBLABEL_THUMBNAILS,
      "Type of thumbnail to display."
      )
MSG_HASH(
      MENU_ENUM_SUBLABEL_TIMEDATE_ENABLE,
      "Shows current date and/or time inside the menu."
      )
MSG_HASH(
      MENU_ENUM_SUBLABEL_BATTERY_LEVEL_ENABLE,
      "Shows current battery level inside the menu."
      )
MSG_HASH(
      MENU_ENUM_SUBLABEL_NAVIGATION_WRAPAROUND,
      "Wrap-around to beginning and/or end if boundary of list is reached horizontally or vertically."
      )
MSG_HASH(
      MENU_ENUM_SUBLABEL_NETPLAY_ENABLE_HOST,
      "Enables netplay in host (server) mode."
      )
MSG_HASH(MENU_ENUM_SUBLABEL_NETPLAY_ENABLE_CLIENT,
      "Enables netplay in client mode.")
MSG_HASH(MENU_ENUM_SUBLABEL_NETPLAY_DISCONNECT,
      "Disconnects an active Netplay connection.")
MSG_HASH(MENU_ENUM_SUBLABEL_SCAN_DIRECTORY,
      "Scans a directory for compatible files and add them to the collection.")
MSG_HASH(MENU_ENUM_SUBLABEL_SCAN_FILE,
      "Scans a compatible file and add it to the collection.")
MSG_HASH(MENU_ENUM_SUBLABEL_VIDEO_SWAP_INTERVAL,
      "Uses a custom swap interval for Vsync. Set this to effectively halve monitor refresh rate."
      )
MSG_HASH(MENU_ENUM_SUBLABEL_SORT_SAVEFILES_ENABLE,
      "Sort save files in folders named after the core used."
      )
MSG_HASH(MENU_ENUM_SUBLABEL_SORT_SAVESTATES_ENABLE,
      "Sort save states in folders named after the core used."
      )
MSG_HASH(MENU_ENUM_SUBLABEL_CORE_UPDATER_BUILDBOT_URL,
      "URL to core updater directory on the Libretro buildbot.")
MSG_HASH(MENU_ENUM_SUBLABEL_BUILDBOT_ASSETS_URL,
      "URL to assets updater directory on the Libretro buildbot.")
MSG_HASH(MENU_ENUM_SUBLABEL_CORE_UPDATER_AUTO_EXTRACT_ARCHIVE,
      "After downloading, automatically extract files contained in the downloaded archives."
      )
MSG_HASH(MENU_ENUM_SUBLABEL_NETPLAY_REFRESH_ROOMS,
      "Scan for new rooms.")
MSG_HASH(MENU_ENUM_SUBLABEL_DELETE_ENTRY,
      "Remove this entry from the collection.")
MSG_HASH(MENU_ENUM_SUBLABEL_INFORMATION,
      "View more information about the content.")
MSG_HASH(MENU_ENUM_SUBLABEL_RUN,
      "Start the content.")
MSG_HASH(MENU_ENUM_SUBLABEL_MENU_FILE_BROWSER_SETTINGS,
      "Adjusts filebrowser settings.")
MSG_HASH(
      MENU_ENUM_SUBLABEL_AUTO_REMAPS_ENABLE,
      "Enable customized controls by default at startup."
      )
MSG_HASH(
      MENU_ENUM_SUBLABEL_AUTO_OVERRIDES_ENABLE,
      "Enable customized configuration by default at startup."
      )
MSG_HASH(MENU_ENUM_SUBLABEL_GAME_SPECIFIC_OPTIONS,
      "Enable customized core options by default at startup.")
MSG_HASH(MENU_ENUM_SUBLABEL_CORE_ENABLE,
      "Shows current core name inside menu.")
MSG_HASH(MENU_ENUM_SUBLABEL_DATABASE_MANAGER,
      "View databases.")
MSG_HASH(MENU_ENUM_SUBLABEL_CURSOR_MANAGER,
      "View previous searches.")
MSG_HASH(MENU_ENUM_SUBLABEL_TAKE_SCREENSHOT,
      "Captures an image of the screen.")
MSG_HASH(
      MENU_ENUM_SUBLABEL_CLOSE_CONTENT,
      "Closes the current content. Any unsaved changes might be lost."
      )
MSG_HASH(MENU_ENUM_SUBLABEL_LOAD_STATE,
      "Load a saved state from the currently selected slot.")
MSG_HASH(MENU_ENUM_SUBLABEL_SAVE_STATE,
      "Save a state to the currently selected slot.")
MSG_HASH(MENU_ENUM_SUBLABEL_RESUME,
      "Resume the currently running content and leave the Quick Menu.")
MSG_HASH(MENU_ENUM_SUBLABEL_RESUME_CONTENT,
      "Resume the currently running content and leave the Quick Menu.")
MSG_HASH(MENU_ENUM_SUBLABEL_STATE_SLOT,
      "Changes the currently selected state slot.")
MSG_HASH(MENU_ENUM_SUBLABEL_UNDO_LOAD_STATE,
      "If a state was loaded, content will go back to the state prior to loading.")
MSG_HASH(MENU_ENUM_SUBLABEL_UNDO_SAVE_STATE,
      "If a state was overwritten, it will roll back to the previous save state.")
MSG_HASH(
      MENU_ENUM_SUBLABEL_ACCOUNTS_RETRO_ACHIEVEMENTS,
      "Retro Achievements service. For more information, visit http://retroachievements.org"
      )
MSG_HASH(
      MENU_ENUM_SUBLABEL_ACCOUNTS_LIST,
      "Manages currently configured accounts."
      )
MSG_HASH(MENU_ENUM_SUBLABEL_INPUT_META_REWIND,
      "Manages rewind settings.")
MSG_HASH(MENU_ENUM_SUBLABEL_RESTART_CONTENT,
      "Restarts the content from the beginning.")
MSG_HASH(MENU_ENUM_SUBLABEL_SAVE_CURRENT_CONFIG_OVERRIDE_CORE,
      "Saves an override configuration file which will apply for all content loaded with this core. Will take precedence over the main configuration.")
MSG_HASH(MENU_ENUM_SUBLABEL_SAVE_CURRENT_CONFIG_OVERRIDE_GAME,
      "Saves an override configuration file which will apply for the current content only. Will take precedence over the main configuration.")
MSG_HASH(MENU_ENUM_SUBLABEL_CORE_CHEAT_OPTIONS,
      "Set up cheat codes.")
MSG_HASH(MENU_ENUM_SUBLABEL_SHADER_OPTIONS,
      "Set up shaders to visually augment the image.")
MSG_HASH(MENU_ENUM_SUBLABEL_CORE_INPUT_REMAPPING_OPTIONS,
      "Change the controls for the currently running content.")
MSG_HASH(MENU_ENUM_SUBLABEL_CORE_OPTIONS,
      "Change the options for the currently running content.")
MSG_HASH(MENU_ENUM_SUBLABEL_SHOW_ADVANCED_SETTINGS,
      "Show advanced settings for power users (hidden by default).")
MSG_HASH(MENU_ENUM_SUBLABEL_THREADED_DATA_RUNLOOP_ENABLE,
      "Perform tasks on a separate thread.")
MSG_HASH(MENU_ENUM_SUBLABEL_PLAYLIST_ENTRY_REMOVE,
      "Allow the user to remove entries from collections.")
MSG_HASH(MENU_ENUM_SUBLABEL_SYSTEM_DIRECTORY,
      "Sets the System directory. Cores can query for this directory to load BIOSes, system-specific configs, etc.")
MSG_HASH(MENU_ENUM_SUBLABEL_RGUI_BROWSER_DIRECTORY,
      "Sets start directory for the filebrowser.")
MSG_HASH(
      MENU_ENUM_SUBLABEL_CONTENT_DIR,
      "Usually set by developers who bundle libretro/RetroArch apps to point to assets."
      )
MSG_HASH(MENU_ENUM_SUBLABEL_DYNAMIC_WALLPAPERS_DIRECTORY,
      "Directory to store wallpapers dynamically loaded by the menu depending on context.")
MSG_HASH(MENU_ENUM_SUBLABEL_THUMBNAILS_DIRECTORY,
      "Supplementary thumbnails (boxarts/misc. images, etc.) are stored here."
      )
MSG_HASH(MENU_ENUM_SUBLABEL_RGUI_CONFIG_DIRECTORY,
      "Sets start directory for menu configuration browser.")
MSG_HASH(MENU_ENUM_SUBLABEL_NETPLAY_INPUT_LATENCY_FRAMES_MIN,
      "The number of frames of input latency for netplay to use to hide network latency. Reduces jitter and makes netplay less CPU-intensive, at the expense of noticeable input lag.")
MSG_HASH(MENU_ENUM_SUBLABEL_NETPLAY_INPUT_LATENCY_FRAMES_RANGE,
      "The range of frames of input latency that may be used to hide network latency. Reduces jitter and makes netplay less CPU-intensive, at the expense of unpredictable input lag.")
MSG_HASH(MENU_ENUM_SUBLABEL_DISK_CYCLE_TRAY_STATUS,
      "Cycle the current disk. If the disk is inserted, it will eject the disk. If the disk has not been inserted, it will be inserted. ")
MSG_HASH(MENU_ENUM_SUBLABEL_DISK_INDEX,
      "Change the disk index.")
MSG_HASH(MENU_ENUM_SUBLABEL_DISK_OPTIONS,
      "Disk image management.")
MSG_HASH(MENU_ENUM_SUBLABEL_DISK_IMAGE_APPEND,
      "Select a disk image to insert.")
MSG_HASH(MENU_ENUM_SUBLABEL_MENU_ENUM_THROTTLE_FRAMERATE,
      "Makes sure the framerate is capped while inside the menu.")
MSG_HASH(MENU_ENUM_SUBLABEL_XMB_LAYOUT,
      "Select a different layout for the XMB interface.")
MSG_HASH(MENU_ENUM_SUBLABEL_XMB_THEME,
      "Select a different theme for the icon. Changes will take effect after you restart the program.")
MSG_HASH(MENU_ENUM_SUBLABEL_XMB_SHADOWS_ENABLE,
      "Enable drop shadows for all icons. This will have a minor performance hit.")
MSG_HASH(MENU_ENUM_SUBLABEL_MATERIALUI_MENU_COLOR_THEME,
      "Select a different background color gradient theme.")
MSG_HASH(MENU_ENUM_SUBLABEL_MENU_WALLPAPER_OPACITY,
      "Modify the opacity of the background wallpaper.")
MSG_HASH(MENU_ENUM_SUBLABEL_XMB_MENU_COLOR_THEME,
      "Select a different background color gradient theme.")
MSG_HASH(MENU_ENUM_SUBLABEL_XMB_RIBBON_ENABLE,
      "Select an animated background effect. Can be GPU-intensive depending on the effect. If performance is unsatisfactory, either turn this off or revert to a simpler effect.")
MSG_HASH(MENU_ENUM_SUBLABEL_XMB_FONT,
      "Select a different main font to be used by the menu.")
MSG_HASH(MENU_ENUM_SUBLABEL_CONTENT_SHOW_IMAGES,
      "Show the image tab inside the main menu.")
MSG_HASH(MENU_ENUM_SUBLABEL_CONTENT_SHOW_MUSIC,
      "Show the music tab inside the main menu.")
MSG_HASH(MENU_ENUM_SUBLABEL_CONTENT_SHOW_VIDEO,
      "Show the video tab inside the main menu.")
MSG_HASH(MENU_ENUM_SUBLABEL_CONTENT_SHOW_NETPLAY,
      "Show the netplay tab inside the main menu.")
MSG_HASH(MENU_ENUM_SUBLABEL_CONTENT_SHOW_SETTINGS,
      "Show the settings tab inside the main menu.")
MSG_HASH(MENU_ENUM_SUBLABEL_CONTENT_SHOW_HISTORY,
      "Show the recent history tab inside the main menu.")
MSG_HASH(MENU_ENUM_SUBLABEL_CONTENT_SHOW_ADD,
      "Show the import content tab inside the main menu.")
MSG_HASH(MENU_ENUM_SUBLABEL_CONTENT_SHOW_PLAYLISTS,
      "Show playlist tabs inside the main menu.")
MSG_HASH(MENU_ENUM_SUBLABEL_RGUI_SHOW_START_SCREEN,
      "Show startup screen in menu. This is automatically set to false after the program starts for the first time.")
MSG_HASH(MENU_ENUM_SUBLABEL_MATERIALUI_MENU_HEADER_OPACITY,
      "Modify the opacity of the header graphic.")
MSG_HASH(MENU_ENUM_SUBLABEL_MATERIALUI_MENU_FOOTER_OPACITY,
      "Modify the opacity of the footer graphic.")
MSG_HASH(MENU_ENUM_SUBLABEL_DPI_OVERRIDE_ENABLE,
      "The menu normally scales itself dynamically. If you want to set a specific scaling size instead, enable this.")
MSG_HASH(MENU_ENUM_SUBLABEL_DPI_OVERRIDE_VALUE,
      "Set the custom scaling size here. NOTE: You have to enable 'DPI Override' for this scaling size to take effect.")
MSG_HASH(MENU_ENUM_SUBLABEL_CORE_ASSETS_DIRECTORY,
      "Save all downloaded files to this directory.")
MSG_HASH(MENU_ENUM_SUBLABEL_INPUT_REMAPPING_DIRECTORY,
      "Save all remapped controls to this directory.")
MSG_HASH(MENU_ENUM_SUBLABEL_LIBRETRO_DIR_PATH,
      "Directory where the program searches for content/cores.")
MSG_HASH(MENU_ENUM_SUBLABEL_LIBRETRO_INFO_PATH,
      "Application/core information files are stored here.")
MSG_HASH(MENU_ENUM_SUBLABEL_JOYPAD_AUTOCONFIG_DIR,
      "If a joypad is plugged in, that joypad will be autoconfigured if a config file corresponding to it is present inside this directory.")
MSG_HASH(MENU_ENUM_SUBLABEL_PLAYLIST_DIRECTORY,
      "Save all collections to this directory.")
MSG_HASH(
      MENU_ENUM_SUBLABEL_CACHE_DIRECTORY,
      "If set to a directory, content which is temporarily extracted (e.g. from archives) will be extracted to this directory."
      )
MSG_HASH(MENU_ENUM_SUBLABEL_CURSOR_DIRECTORY,
      "Saved queries are stored to this directory.")
MSG_HASH(
      MENU_ENUM_SUBLABEL_CONTENT_DATABASE_DIRECTORY,
      "Databases are stored to this directory."
      )
MSG_HASH(
      MENU_ENUM_SUBLABEL_ASSETS_DIRECTORY,
      "This location is queried by default when menu interfaces try to look for loadable assets, etc."
      )
MSG_HASH(MENU_ENUM_SUBLABEL_SAVEFILE_DIRECTORY,
      "Save all save files to this directory. If not set, will try to save inside the content file's working directory.")
MSG_HASH(MENU_ENUM_SUBLABEL_SAVESTATE_DIRECTORY,
      "Save all save states to this directory. If not set, will try to save inside the content file's working directory.")
MSG_HASH(MENU_ENUM_SUBLABEL_SCREENSHOT_DIRECTORY,
      "Directory to dump screenshots to.")
MSG_HASH(MENU_ENUM_SUBLABEL_OVERLAY_DIRECTORY,
      "Defines a directory where overlays are kept for easy access.")
MSG_HASH(
      MENU_ENUM_SUBLABEL_CHEAT_DATABASE_PATH,
      "Cheat files are kept here."
      )
MSG_HASH(
      MENU_ENUM_SUBLABEL_AUDIO_FILTER_DIR,
      "Directory where audio DSP filter files are kept."
      )
MSG_HASH(
      MENU_ENUM_SUBLABEL_VIDEO_FILTER_DIR,
      "Directory where CPU-based video filter files are kept."
      )
MSG_HASH(MENU_ENUM_SUBLABEL_VIDEO_SHADER_DIR,
      "Defines a directory where GPU-based video shader files are kept for easy access.")
MSG_HASH(MENU_ENUM_SUBLABEL_RECORDING_OUTPUT_DIRECTORY,
      "Recordings will be dumped to this directory.")
MSG_HASH(MENU_ENUM_SUBLABEL_RECORDING_CONFIG_DIRECTORY,
      "Recording configurations will be kept here.")
MSG_HASH(MENU_ENUM_SUBLABEL_VIDEO_FONT_PATH,
      "Select a different font for onscreen notifications.")
MSG_HASH(MENU_ENUM_SUBLABEL_SHADER_APPLY_CHANGES,
      "Changes to the shader configuration will take effect immediately. Use this if you changed the amount of shader passes, filtering, FBO scale, etc.")
MSG_HASH(
      MENU_ENUM_SUBLABEL_VIDEO_SHADER_NUM_PASSES,
      "Increase or decrease the amount of shader pipeline passes. You can bind a separate shader to each pipeline pass and configure its scale and filtering."
      )
MSG_HASH(MENU_ENUM_SUBLABEL_VIDEO_SHADER_PRESET,
      "Load a shader preset. The shader pipeline will be automatically set-up.")
MSG_HASH(MENU_ENUM_SUBLABEL_VIDEO_SHADER_PRESET_SAVE_AS,
      "Save the current shader settings as a new shader preset.")
MSG_HASH(MENU_ENUM_SUBLABEL_VIDEO_SHADER_PRESET_SAVE_CORE,
      "Save the current shader settings as the default settings for this application/core.")
MSG_HASH(MENU_ENUM_SUBLABEL_VIDEO_SHADER_PRESET_SAVE_GAME,
      "Save the current shader settings as the default settings for the content.")
MSG_HASH(MENU_ENUM_SUBLABEL_VIDEO_SHADER_PARAMETERS,
      "Modifies the current shader directly. Changes will not be saved to the preset file.")
MSG_HASH(MENU_ENUM_SUBLABEL_VIDEO_SHADER_PRESET_PARAMETERS,
      "Modifies the shader preset itself currently used in the menu.")
MSG_HASH(
      MENU_ENUM_SUBLABEL_CHEAT_NUM_PASSES,
      "Increase or decrease the amount of cheats."
      )
MSG_HASH(MENU_ENUM_SUBLABEL_CHEAT_APPLY_CHANGES,
      "Cheat changes will take effect immediately.")
MSG_HASH(
      MENU_ENUM_SUBLABEL_CHEAT_FILE_LOAD,
      "Load a cheat file."
      )
MSG_HASH(
      MENU_ENUM_SUBLABEL_CHEAT_FILE_SAVE_AS,
      "Save current cheats as a save file."
      )
MSG_HASH(MENU_ENUM_SUBLABEL_CONTENT_SETTINGS,
      "Quickly access all relevant in-game settings.")
MSG_HASH(MENU_ENUM_SUBLABEL_CORE_INFORMATION,
      "View information pertaining to the application/core.")
MSG_HASH(MENU_ENUM_SUBLABEL_VIDEO_ASPECT_RATIO,
      "Floating point value for video aspect ratio (width / height), used if the Aspect Ratio is set to 'Config'.")
MSG_HASH(MENU_ENUM_SUBLABEL_VIDEO_VIEWPORT_CUSTOM_HEIGHT,
      "Custom viewport height that is used if the Aspect Ratio is set to 'Custom'.")
MSG_HASH(MENU_ENUM_SUBLABEL_VIDEO_VIEWPORT_CUSTOM_WIDTH,
      "Custom viewport width that is used if the Aspect Ratio is set to 'Custom'.")
MSG_HASH(MENU_ENUM_SUBLABEL_VIDEO_VIEWPORT_CUSTOM_X,
      "Custom viewport offset used for defining the X-axis position of the viewport. These are ignored if 'Integer Scale' is enabled. It will be automatically centered then.")
MSG_HASH(MENU_ENUM_SUBLABEL_VIDEO_VIEWPORT_CUSTOM_Y,
      "Custom viewport offset used for defining the Y-axis position of the viewport. These are ignored if 'Integer Scale' is enabled. It will be automatically centered then.")
MSG_HASH(MENU_ENUM_LABEL_VALUE_NETPLAY_USE_MITM_SERVER,
      "Use Relay Server")
MSG_HASH(MENU_ENUM_SUBLABEL_NETPLAY_USE_MITM_SERVER,
      "Forward netplay connections through a man-in-the-middle server. Useful if the host is behind a firewall or has NAT/UPnP problems.")
MSG_HASH(MENU_ENUM_LABEL_VALUE_ADD_TO_MIXER,
      "Add to mixer")
MSG_HASH(MENU_ENUM_LABEL_VALUE_ADD_TO_MIXER_AND_PLAY,
      "Add to mixer and play")
MSG_HASH(MENU_ENUM_LABEL_VALUE_ADD_TO_MIXER_AND_COLLECTION,
      "Add to mixer")
MSG_HASH(MENU_ENUM_LABEL_VALUE_ADD_TO_MIXER_AND_COLLECTION_AND_PLAY,
      "Add to mixer and play")
MSG_HASH(MENU_ENUM_LABEL_VALUE_FILTER_BY_CURRENT_CORE,
      "Filter by current core")
MSG_HASH(
      MSG_AUDIO_MIXER_VOLUME,
      "Global audio mixer volume"
      )
MSG_HASH(
      MENU_ENUM_SUBLABEL_AUDIO_MIXER_VOLUME,
      "Global audio mixer volume (in dB). 0 dB is normal volume, and no gain is applied."
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_AUDIO_MIXER_VOLUME,
      "Audio Mixer Volume Level (dB)"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_AUDIO_MIXER_MUTE,
      "Audio Mixer Mute"
      )
MSG_HASH(MENU_ENUM_SUBLABEL_AUDIO_MIXER_MUTE,
      "Mute/unmute mixer audio.")
MSG_HASH(MENU_ENUM_LABEL_MENU_SHOW_ONLINE_UPDATER,
      "Show Online Updater")
MSG_HASH(MENU_ENUM_SUBLABEL_MENU_SHOW_ONLINE_UPDATER,
      "Show/hide the 'Online Updater' option.")
MSG_HASH(MENU_ENUM_LABEL_VALUE_MENU_SHOW_CORE_UPDATER,
      "Show Core Updater")
MSG_HASH(MENU_ENUM_SUBLABEL_MENU_SHOW_CORE_UPDATER,
      "Show/hide the ability to update cores (and core info files).")
MSG_HASH(MSG_PREPARING_FOR_CONTENT_SCAN,
      "Preparing for content scan...")
MSG_HASH(MENU_ENUM_LABEL_VALUE_CORE_DELETE,
      "Delete core")
MSG_HASH(MENU_ENUM_SUBLABEL_CORE_DELETE,
      "Remove this core from disk.")
MSG_HASH(MENU_ENUM_LABEL_VALUE_RENAME_ENTRY,
      "Rename the title of the entry.")
MSG_HASH(MENU_ENUM_LABEL_RENAME_ENTRY,
      "Rename")
MSG_HASH(MENU_ENUM_LABEL_VALUE_MENU_FRAMEBUFFER_OPACITY,
      "Framebuffer Opacity")
MSG_HASH(MENU_ENUM_SUBLABEL_MENU_FRAMEBUFFER_OPACITY,
      "Modify the opacity of the framebuffer.")
MSG_HASH(MENU_ENUM_LABEL_VALUE_GOTO_FAVORITES,
      "Favorites")
MSG_HASH(MENU_ENUM_SUBLABEL_GOTO_FAVORITES,
      "Content which you have added to 'Favorites' will appear here.")
MSG_HASH(MENU_ENUM_LABEL_VALUE_GOTO_MUSIC,
      "Music")
MSG_HASH(MENU_ENUM_SUBLABEL_GOTO_MUSIC,
      "Music which has been previously played will appear here.")
MSG_HASH(MENU_ENUM_LABEL_VALUE_GOTO_IMAGES,
      "Image")
MSG_HASH(MENU_ENUM_SUBLABEL_GOTO_IMAGES,
      "Images which have been previously viewed will appear here.")
MSG_HASH(MENU_ENUM_LABEL_VALUE_GOTO_VIDEO,
      "Video")
MSG_HASH(MENU_ENUM_SUBLABEL_GOTO_VIDEO,
      "Videos which have been previously played will appear here.")
MSG_HASH(MENU_ENUM_LABEL_VALUE_MATERIALUI_ICONS_ENABLE,
      "Menu Icons")
MSG_HASH(MENU_ENUM_SUBLABEL_MATERIALUI_ICONS_ENABLE,
      "Enable/disable the menu icons shown at the lefthand side of the menu entries.")
MSG_HASH(MENU_ENUM_LABEL_VALUE_XMB_MAIN_MENU_ENABLE_SETTINGS,
      "Enable Settings Tab")
MSG_HASH(MENU_ENUM_LABEL_VALUE_CONTENT_SHOW_SETTINGS_PASSWORD,
      "Set Password For Enabling Settings Tab")
MSG_HASH(MSG_INPUT_ENABLE_SETTINGS_PASSWORD,
      "Enter Password")
MSG_HASH(MSG_INPUT_ENABLE_SETTINGS_PASSWORD_OK,
      "Password correct.")
MSG_HASH(MSG_INPUT_ENABLE_SETTINGS_PASSWORD_NOK,
      "Password incorrect.")
MSG_HASH(MENU_ENUM_SUBLABEL_XMB_MAIN_MENU_ENABLE_SETTINGS,
      "Enables the Settings tab. A restart is required for the tab to appear.")
MSG_HASH(MENU_ENUM_SUBLABEL_CONTENT_SHOW_SETTINGS_PASSWORD,
      "Supplying a password when hiding the settings tab makes it possible to later restore it from the menu, by going to the Main Menu tab, selecting Enable Settings Tab and entering the password.")
MSG_HASH(MENU_ENUM_SUBLABEL_PLAYLIST_ENTRY_RENAME,
      "Allow the user to rename entries in collections.")
MSG_HASH(MENU_ENUM_LABEL_VALUE_PLAYLIST_ENTRY_RENAME,
      "Allow to rename entries")
MSG_HASH(MENU_ENUM_LABEL_VALUE_MENU_SHOW_LOAD_CORE,
      "Show Load Core")
MSG_HASH(MENU_ENUM_SUBLABEL_MENU_SHOW_LOAD_CORE,
      "Show/hide the 'Load Core' option.")
MSG_HASH(MENU_ENUM_LABEL_VALUE_MENU_SHOW_LOAD_CONTENT,
      "Show Load Content")
MSG_HASH(MENU_ENUM_SUBLABEL_MENU_SHOW_LOAD_CONTENT,
      "Show/hide the 'Load Content' option.")
MSG_HASH(MENU_ENUM_LABEL_VALUE_MENU_SHOW_INFORMATION,
      "Show Information")
MSG_HASH(MENU_ENUM_SUBLABEL_MENU_SHOW_INFORMATION,
      "Show/hide the 'Information' option.")
MSG_HASH(MENU_ENUM_LABEL_VALUE_MENU_SHOW_CONFIGURATIONS,
      "Show Configurations")
MSG_HASH(MENU_ENUM_SUBLABEL_MENU_SHOW_CONFIGURATIONS,
      "Show/hide the 'Configurations' option.")
MSG_HASH(MENU_ENUM_LABEL_VALUE_MENU_SHOW_HELP,
      "Show Help")
MSG_HASH(MENU_ENUM_SUBLABEL_MENU_SHOW_HELP,
      "Show/hide the 'Help' option.")
MSG_HASH(MENU_ENUM_LABEL_VALUE_MENU_SHOW_QUIT_RETROARCH,
      "Show Quit RetroArch")
MSG_HASH(MENU_ENUM_SUBLABEL_MENU_SHOW_QUIT_RETROARCH,
      "Show/hide the 'Quit RetroArch' option.")
MSG_HASH(MENU_ENUM_LABEL_VALUE_MENU_SHOW_REBOOT,
      "Show Reboot")
MSG_HASH(MENU_ENUM_SUBLABEL_MENU_SHOW_REBOOT,
      "Show/hide the 'Reboot' option.")
MSG_HASH(MENU_ENUM_LABEL_VALUE_QUICK_MENU_VIEWS_SETTINGS,
      "Quick Menu")
MSG_HASH(MENU_ENUM_SUBLABEL_QUICK_MENU_VIEWS_SETTINGS,
      "Show or hide elements on the Quick Menu screen.")
MSG_HASH(MENU_ENUM_LABEL_VALUE_QUICK_MENU_SHOW_TAKE_SCREENSHOT,
      "Show Take Screenshot")
MSG_HASH(MENU_ENUM_SUBLABEL_QUICK_MENU_SHOW_TAKE_SCREENSHOT,
      "Show/hide the 'Take Screenshot' option.")
MSG_HASH(MENU_ENUM_LABEL_VALUE_QUICK_MENU_SHOW_SAVE_LOAD_STATE,
      "Show Save/Load State")
MSG_HASH(MENU_ENUM_SUBLABEL_QUICK_MENU_SHOW_SAVE_LOAD_STATE,
      "Show/hide the options for saving/loading state.")
MSG_HASH(MENU_ENUM_LABEL_VALUE_QUICK_MENU_SHOW_UNDO_SAVE_LOAD_STATE,
      "Show Undo Save/Load State")
MSG_HASH(MENU_ENUM_SUBLABEL_QUICK_MENU_SHOW_UNDO_SAVE_LOAD_STATE,
      "Show/hide the options for undoing save/load state.")
MSG_HASH(MENU_ENUM_LABEL_VALUE_QUICK_MENU_SHOW_ADD_TO_FAVORITES,
      "Show Add to Favorites")
MSG_HASH(MENU_ENUM_SUBLABEL_QUICK_MENU_SHOW_ADD_TO_FAVORITES,
      "Show/hide the 'Add to Favorites' option.")
MSG_HASH(MENU_ENUM_LABEL_VALUE_QUICK_MENU_SHOW_OPTIONS,
      "Show Options")
MSG_HASH(MENU_ENUM_SUBLABEL_QUICK_MENU_SHOW_OPTIONS,
      "Show/hide the 'Options' option.")
MSG_HASH(MENU_ENUM_LABEL_VALUE_QUICK_MENU_SHOW_CONTROLS,
      "Show Controls")
MSG_HASH(MENU_ENUM_SUBLABEL_QUICK_MENU_SHOW_CONTROLS,
      "Show/hide the 'Controls' option.")
MSG_HASH(MENU_ENUM_LABEL_VALUE_QUICK_MENU_SHOW_CHEATS,
      "Show Cheats")
MSG_HASH(MENU_ENUM_SUBLABEL_QUICK_MENU_SHOW_CHEATS,
      "Show/hide the 'Cheats' option.")
MSG_HASH(MENU_ENUM_LABEL_VALUE_QUICK_MENU_SHOW_SHADERS,
      "Show Shaders")
MSG_HASH(MENU_ENUM_SUBLABEL_QUICK_MENU_SHOW_SHADERS,
      "Show/hide the 'Shaders' option.")
MSG_HASH(MENU_ENUM_LABEL_VALUE_QUICK_MENU_SHOW_SAVE_CORE_OVERRIDES,
      "Show Save Core Overrides")
MSG_HASH(MENU_ENUM_SUBLABEL_QUICK_MENU_SHOW_SAVE_CORE_OVERRIDES,
      "Show/hide the 'Save Core Overrides' option.")
MSG_HASH(MENU_ENUM_LABEL_VALUE_QUICK_MENU_SHOW_SAVE_GAME_OVERRIDES,
      "Show Save Game Overrides")
MSG_HASH(MENU_ENUM_SUBLABEL_QUICK_MENU_SHOW_SAVE_GAME_OVERRIDES,
      "Show/hide the 'Save Game Overrides' option.")
MSG_HASH(MENU_ENUM_LABEL_VALUE_QUICK_MENU_SHOW_INFORMATION,
      "Show Information")
MSG_HASH(MENU_ENUM_SUBLABEL_QUICK_MENU_SHOW_INFORMATION,
      "Show/hide the 'Information' option.")
MSG_HASH(MENU_ENUM_LABEL_VALUE_MENU_DISABLE_KIOSK_MODE,
      "Disable Kiosk Mode")
MSG_HASH(MENU_ENUM_SUBLABEL_MENU_DISABLE_KIOSK_MODE,
      "Disables kiosk mode. A restart is required for the change to take full effect.")
MSG_HASH(MENU_ENUM_LABEL_VALUE_MENU_ENABLE_KIOSK_MODE,
      "Enable Kiosk Mode")
MSG_HASH(MENU_ENUM_SUBLABEL_MENU_ENABLE_KIOSK_MODE,
      "Protects the setup by hiding all configuration related settings.")
MSG_HASH(MENU_ENUM_LABEL_VALUE_MENU_KIOSK_MODE_PASSWORD,
      "Set Password For Disabling Kiosk Mode")
MSG_HASH(MENU_ENUM_SUBLABEL_MENU_KIOSK_MODE_PASSWORD,
      "Supplying a password when enabling kiosk mode makes it possible to later disable it from the menu, by going to the Main Menu, selecting Disable Kiosk Mode and entering the password.")
MSG_HASH(MSG_INPUT_KIOSK_MODE_PASSWORD,
      "Enter Password")
MSG_HASH(MSG_INPUT_KIOSK_MODE_PASSWORD_OK,
      "Password correct.")
MSG_HASH(MSG_INPUT_KIOSK_MODE_PASSWORD_NOK,
      "Password incorrect.")
MSG_HASH(MENU_ENUM_LABEL_VALUE_AUTOMATICALLY_ADD_CONTENT_TO_PLAYLIST,
      "Automatically add content to playlist")
MSG_HASH(MENU_ENUM_SUBLABEL_AUTOMATICALLY_ADD_CONTENT_TO_PLAYLIST,
      "Automatically scans loaded content so they appear inside playlists.")
MSG_HASH(MSG_SCANNING_OF_FILE_FINISHED,
      "Scanning of file finished")
MSG_HASH(MENU_ENUM_LABEL_VALUE_AUDIO_RESAMPLER_QUALITY,
      "Audio Resampler Quality")
MSG_HASH(MENU_ENUM_SUBLABEL_AUDIO_RESAMPLER_QUALITY,
      "Lower this value to favor performance/lower latency over audio quality, increase if you want better audio quality at the expense of performance/lower latency.")
MSG_HASH(MENU_ENUM_LABEL_VALUE_STATISTICS_SHOW,
      "Display Statistics")
MSG_HASH(MENU_ENUM_SUBLABEL_STATISTICS_SHOW,
      "Show onscreen technical statistics.")
MSG_HASH(MENU_ENUM_LABEL_VALUE_MENU_RGUI_BORDER_FILLER_ENABLE,
      "Enable border filler")
MSG_HASH(MENU_ENUM_LABEL_VALUE_MENU_RGUI_BORDER_FILLER_THICKNESS_ENABLE,
      "Enable border filler thickness")
MSG_HASH(MENU_ENUM_LABEL_VALUE_MENU_RGUI_BACKGROUND_FILLER_THICKNESS_ENABLE,
      "Enable background filler thickness")
MSG_HASH(MENU_ENUM_SUBLABEL_CRT_SWITCH_RESOLUTION, "For 15 kHz CRT displays only. Attempts to use exact core/game resolution and refresh rate.")
MSG_HASH(MENU_ENUM_LABEL_VALUE_CRT_SWITCH_RESOLUTION, "CRT SwitchRes") 
MSG_HASH(MENU_ENUM_SUBLABEL_CRT_SWITCH_RESOLUTION_SUPER, "When CRT SwitchRes is enabled, force ultrawide horizontal resolution to minimize mode switching.")
MSG_HASH(MENU_ENUM_LABEL_VALUE_CRT_SWITCH_RESOLUTION_SUPER, "CRT Super Resolution") 
MSG_HASH(MENU_ENUM_LABEL_VALUE_CONTENT_SHOW_REWIND,
      "Show Rewind Settings")
MSG_HASH(MENU_ENUM_SUBLABEL_CONTENT_SHOW_REWIND,
      "Show/hide the Rewind options.")
MSG_HASH(MENU_ENUM_SUBLABEL_CONTENT_SHOW_LATENCY,
      "Show/hide the Latency options.")
MSG_HASH(MENU_ENUM_LABEL_VALUE_CONTENT_SHOW_LATENCY,
      "Show Latency Settings")
MSG_HASH(MENU_ENUM_SUBLABEL_CONTENT_SHOW_OVERLAYS,
      "Show/hide the Overlay options.")
MSG_HASH(MENU_ENUM_LABEL_VALUE_CONTENT_SHOW_OVERLAYS,
      "Show Overlay Settings")
MSG_HASH(MENU_ENUM_LABEL_VALUE_AUDIO_ENABLE_MENU,
      "Enable menu audio")
MSG_HASH(MENU_ENUM_SUBLABEL_AUDIO_ENABLE_MENU,
      "Enable or disable menu sound.")
MSG_HASH(MENU_ENUM_LABEL_VALUE_AUDIO_MIXER_SETTINGS,
      "Mixer Settings")
MSG_HASH(MENU_ENUM_SUBLABEL_AUDIO_MIXER_SETTINGS,
      "View and/or modify audio mixer settings.")
MSG_HASH(MENU_ENUM_LABEL_VALUE_QUICK_MENU_OVERRIDE_OPTIONS,
      "Configuration Override options")
MSG_HASH(MENU_ENUM_SUBLABEL_QUICK_MENU_OVERRIDE_OPTIONS,
      "Options for overriding the global configuration.")
MSG_HASH(MENU_ENUM_SUBLABEL_MIXER_ACTION_PLAY,
      "Will start playback of the audio stream. Once finished, it will remove the current audio stream from memory.")
MSG_HASH(MENU_ENUM_SUBLABEL_MIXER_ACTION_PLAY_LOOPED,
      "Will start playback of the audio stream. Once finished, it will loop and play the track again from the beginning.")
MSG_HASH(MENU_ENUM_SUBLABEL_MIXER_ACTION_PLAY_SEQUENTIAL,
      "Will start playback of the audio stream. Once finished, it will jump to the next audio stream in sequential order and repeat this behavior. Useful as an album playback mode.")
MSG_HASH(MENU_ENUM_SUBLABEL_MIXER_ACTION_STOP,
      "This will stop playback of the audio stream, but not remove it from memory. You can start playing it again by selecting 'Play'.")
MSG_HASH(MENU_ENUM_SUBLABEL_MIXER_ACTION_REMOVE,
      "This will stop playback of the audio stream and remove it entirely from memory.")
MSG_HASH(MENU_ENUM_SUBLABEL_MIXER_ACTION_VOLUME,
      "Adjust the volume of the audio stream.")
MSG_HASH(MENU_ENUM_SUBLABEL_ADD_TO_MIXER,
      "Add this audio track to an available audio stream slot. If no slots are currently available, it will be ignored.")
MSG_HASH(MENU_ENUM_SUBLABEL_ADD_TO_MIXER_AND_PLAY,
      "Add this audio track to an available audio stream slot and play it. If no slots are currently available, it will be ignored.")
MSG_HASH(MENU_ENUM_LABEL_VALUE_MIXER_ACTION_PLAY,
      "Play")
MSG_HASH(MENU_ENUM_LABEL_VALUE_MIXER_ACTION_PLAY_LOOPED,
      "Play (Looped)")
MSG_HASH(MENU_ENUM_LABEL_VALUE_MIXER_ACTION_PLAY_SEQUENTIAL,
      "Play (Sequential)")
MSG_HASH(MENU_ENUM_LABEL_VALUE_MIXER_ACTION_STOP,
      "Stop")
MSG_HASH(MENU_ENUM_LABEL_VALUE_MIXER_ACTION_REMOVE,
      "Remove")
MSG_HASH(MENU_ENUM_LABEL_VALUE_MIXER_ACTION_VOLUME,
      "Volume")
